window.Gleam.initSearch([{"doc":"sprocket","title":"sprocket","content":"# Sprocket\nA library for building live views and real-time server components in [Gleam ✨](https://gleam.run/)\n\n[![Package Version](https://img.shields.io/hexpm/v/sprocket)](https://hex.pm/packages/sprocket)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/sprocket/)\n\n[Demo Documentation](https://sprocket.live)\n\nHeavily inspired by [Phoenix LiveView](https://github.com/phoenixframework/phoenix_live_view),\n[React](https://github.com/facebook/react) and [Elm](https://github.com/elm). The name &quot;sprocket&quot;\nis loosely derived from the metaphor of a bicycle&#39;s sprocket, cassette and chain.\n\nSprocket combines the best of LiveView server-side productivity and scalability, React components\nand Elm functional state management patterns implemented in Gleam, a type-safe\nlanguage built on the venerable BEAM (Erlang Virtual Machine).\n\nAn initial static view is rendered as HTML on the &quot;first paint&quot; which then establishes a connection to the server over a\nWebSocket to facilitate sending browser events and receiving view update diffs. These updates are\npatched into a client-side in-memory representation of the DOM and rendered to the browser using\nmorphdom. Declarative views are built using functional components that accept props and re-render\neach time those props change and reducers are used for state management using strongly-typed models\nand message structs.\n\nUnder the hood, a reducer is a lightweight [Gleam\nActor](https://hexdocs.pm/gleam_otp/0.1.3/gleam/otp/actor/) OTP process (i.e. gen_server) and\nchanges to the state (via dispatch) result in a re-render of the view.\n\nComponent interfaces snap together and are used to create higher-level views. Data flow is\n&quot;uni-directional&quot; in that **State** always flows down into components as props while **Events**\nflow up out of components through event handlers (which are also passed in as props, e.g.\n`on_some_event(&quot;Something happened&quot;)`). \n\nThis library is currently in a **proof of concept** state and should be considered highly unstable.\nThere is still a lot of work to be done, including adding support for more event types, introducing additional hooks, improving unit test\ncoverage, providing extensive documentation of modules and API, and optimizing performance. \n\n## Key Features\n\n- Real-time, scalable server-side component library\n- Renders initial HTML and efficiently patches update diffs using a persistent WebSocket connection\n- Declarative and composable functional components that re-render when props change\n- Strongly-typed language means less runtime bugs and better peace of mind\n- Lightweight OTP processes used for composable &amp; scalable state management\n\n## Example\n\n### Clock Component\n```gleam\ntype Model {\n  Model(time: Int, timezone: String)\n}\n\ntype Msg {\n  NoOp\n  UpdateTime(Int)\n}\n\nfn update(model: Model, msg: Msg) -&gt; Model {\n  case msg {\n    NoOp -&gt; model\n    UpdateTime(time) -&gt; {\n      Model(..model, time: time)\n    }\n  }\n}\n\nfn initial() -&gt; Model {\n  Model(time: erlang.system_time(erlang.Second), timezone: &quot;UTC&quot;)\n}\n\npub type ClockProps {\n  ClockProps(label: Option(String))\n}\n\npub fn clock(ctx: Context, props) {\n  let ClockProps(label) = props\n\n  // Define a reducer to handle events and update the state\n  use ctx, Model(time: time, ..), dispatch &lt;- reducer(\n    ctx,\n    initial(),\n    update,\n  )\n\n  // Example effect that runs whenever the `time` variable changes and has a cleanup function\n  use ctx &lt;- effect(\n    ctx,\n    fn() {\n      let cancel =\n        interval(\n          1000,\n          fn() { dispatch(UpdateTime(erlang.system_time(erlang.Second))) },\n        )\n\n      Some(fn() { cancel() })\n    },\n    WithDeps([dep(time)]),\n  )\n\n  let current_time = int.to_string(time)\n\n  render(\n    ctx,\n    case label {\n      Some(label) -&gt; [span([], [text(label)]), span([], [text(current_time)])]\n      None -&gt; [text(current_time)]\n    },\n  )\n}\n```\n\n### Parent view\n```gleam\npub type ExampleViewProps {\n  ExampleViewProps\n}\n\npub fn example_view(ctx: Context, _props: ExampleViewProps) {\n  render(\n    ctx,\n    [\n      html(\n        [lang(&quot;en&quot;)],\n        [\n          head([], [link([rel(&quot;stylesheet&quot;), href(&quot;/app.css&quot;)])]),\n          body(\n            [class(&quot;bg-white dark:bg-gray-900 dark:text-white p-4&quot;)],\n            [\n              component(\n                clock,\n                ClockProps(label: Some(&quot;The current time is: &quot;)),\n              ),\n            ],\n          ),\n        ],\n      ),\n    ],\n  )\n}\n\n```\n\n## Getting Started\n\nTo get started with Sprocket, follow the instructions below:\n\n1. Clone the Sprocket repository:\n```sh\ngit clone https://github.com/bitbldr/sprocket.git\n```\n\n2. Install the required dependencies:\n```sh\ngleam deps download\nyarn\n```\n\n3. Start the development server:\n```sh\nyarn run watch\n```\n\n4. Open your web browser and visit [http://localhost:3000](http://localhost:3000) to see the docs sample app.\n\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add sprocket\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/sprocket&gt;.\n\n\n## Documentation\n\nDocumentation for Sprocket can be found at the [docs sample app](https://sprocket.live).\nIt provides detailed information on how to use Sprocket, including module descriptions, API \nreferences, and examples.\n\n## Roadmap\n\nSprocket is still in its early stages and has a roadmap for future development. Here are some of the planned improvements:\n\n- [x] Build out full set of base HTML functions for components\n- [x] ~~Explore other http and websocket server options~~ Core library is now web server agnostic\n- [ ] Add support for additional event types to handle various user interactions\n- [ ] Expand the available hooks to enable more flexible component behavior\n- [ ] Convert client TypeScript to gleam\n- [ ] Improve unit test coverage to ensure code quality and reliability\n- [ ] Provide extensive documentation of modules and API for easier adoption\n- [ ] Optimize performance to enhance responsiveness and scalability\n- [ ] Investigate extending to support more than just web views, such as native desktop, iOS, and Android applications.\n\n## Contributing\n\nContributions to Sprocket are welcome and encouraged! If you would like to contribute, please follow\nthe guidelines outlined in the\n[CONTRIBUTING.md](https://github.com/bitbldr/sprocket/blob/master/CONTRIBUTING.md) file.\n\n## License\n\nSprocket is released under the [MIT License](https://github.com/bitbldr/sprocket/blob/master/LICENSE.md).\n","url":"index.html"},{"doc":"sprocket/html/attributes","title":"Attribute","content":"pub type Attribute {\n  Attribute(name: String, value: Dynamic)\n  Event(name: String, identifiable_cb: IdentifiableCallback)\n  ClientHook(id: Unique, name: String)\n}\n\nAttribute(name: String, value: Dynamic)\n\n\nEvent(name: String, identifiable_cb: IdentifiableCallback)\n\n\nClientHook(id: Unique, name: String)\n\n\nSynonyms:\nsprocket/html/attributes.Attribute\nsprocket/html/attributes Attribute","url":"sprocket/html/attributes.html#Attribute"},{"doc":"sprocket/html/attributes","title":"accept","content":"pub fn accept(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.accept\nsprocket/html/attributes accept","url":"sprocket/html/attributes.html#accept"},{"doc":"sprocket/html/attributes","title":"accept_charset","content":"pub fn accept_charset(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.accept_charset\nsprocket/html/attributes accept_charset","url":"sprocket/html/attributes.html#accept_charset"},{"doc":"sprocket/html/attributes","title":"action","content":"pub fn action(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.action\nsprocket/html/attributes action","url":"sprocket/html/attributes.html#action"},{"doc":"sprocket/html/attributes","title":"alt","content":"pub fn alt(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.alt\nsprocket/html/attributes alt","url":"sprocket/html/attributes.html#alt"},{"doc":"sprocket/html/attributes","title":"async","content":"pub fn async() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.async\nsprocket/html/attributes async","url":"sprocket/html/attributes.html#async"},{"doc":"sprocket/html/attributes","title":"attribute","content":"pub fn attribute(name: String, value: a) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.attribute\nsprocket/html/attributes attribute","url":"sprocket/html/attributes.html#attribute"},{"doc":"sprocket/html/attributes","title":"autocapitalize","content":"pub fn autocapitalize(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.autocapitalize\nsprocket/html/attributes autocapitalize","url":"sprocket/html/attributes.html#autocapitalize"},{"doc":"sprocket/html/attributes","title":"autocomplete","content":"pub fn autocomplete(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.autocomplete\nsprocket/html/attributes autocomplete","url":"sprocket/html/attributes.html#autocomplete"},{"doc":"sprocket/html/attributes","title":"autofocus","content":"pub fn autofocus() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.autofocus\nsprocket/html/attributes autofocus","url":"sprocket/html/attributes.html#autofocus"},{"doc":"sprocket/html/attributes","title":"autoplay","content":"pub fn autoplay() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.autoplay\nsprocket/html/attributes autoplay","url":"sprocket/html/attributes.html#autoplay"},{"doc":"sprocket/html/attributes","title":"capture","content":"pub fn capture(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.capture\nsprocket/html/attributes capture","url":"sprocket/html/attributes.html#capture"},{"doc":"sprocket/html/attributes","title":"charset","content":"pub fn charset(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.charset\nsprocket/html/attributes charset","url":"sprocket/html/attributes.html#charset"},{"doc":"sprocket/html/attributes","title":"checked","content":"pub fn checked() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.checked\nsprocket/html/attributes checked","url":"sprocket/html/attributes.html#checked"},{"doc":"sprocket/html/attributes","title":"cite","content":"pub fn cite(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.cite\nsprocket/html/attributes cite","url":"sprocket/html/attributes.html#cite"},{"doc":"sprocket/html/attributes","title":"class","content":"pub fn class(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.class\nsprocket/html/attributes class","url":"sprocket/html/attributes.html#class"},{"doc":"sprocket/html/attributes","title":"classes","content":"pub fn classes(value: List(Option(String))) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.classes\nsprocket/html/attributes classes","url":"sprocket/html/attributes.html#classes"},{"doc":"sprocket/html/attributes","title":"client_hook","content":"pub fn client_hook(id: Unique, name: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.client_hook\nsprocket/html/attributes client_hook","url":"sprocket/html/attributes.html#client_hook"},{"doc":"sprocket/html/attributes","title":"content","content":"pub fn content(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.content\nsprocket/html/attributes content","url":"sprocket/html/attributes.html#content"},{"doc":"sprocket/html/attributes","title":"contenteditable","content":"pub fn contenteditable() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.contenteditable\nsprocket/html/attributes contenteditable","url":"sprocket/html/attributes.html#contenteditable"},{"doc":"sprocket/html/attributes","title":"crossorigin","content":"pub fn crossorigin(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.crossorigin\nsprocket/html/attributes crossorigin","url":"sprocket/html/attributes.html#crossorigin"},{"doc":"sprocket/html/attributes","title":"defer","content":"pub fn defer() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.defer\nsprocket/html/attributes defer","url":"sprocket/html/attributes.html#defer"},{"doc":"sprocket/html/attributes","title":"disabled","content":"pub fn disabled() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.disabled\nsprocket/html/attributes disabled","url":"sprocket/html/attributes.html#disabled"},{"doc":"sprocket/html/attributes","title":"draggable","content":"pub fn draggable() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.draggable\nsprocket/html/attributes draggable","url":"sprocket/html/attributes.html#draggable"},{"doc":"sprocket/html/attributes","title":"event","content":"pub fn event(name: String, identifiable_cb: IdentifiableCallback) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.event\nsprocket/html/attributes event","url":"sprocket/html/attributes.html#event"},{"doc":"sprocket/html/attributes","title":"for","content":"pub fn for(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.for\nsprocket/html/attributes for","url":"sprocket/html/attributes.html#for"},{"doc":"sprocket/html/attributes","title":"formaction","content":"pub fn formaction(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.formaction\nsprocket/html/attributes formaction","url":"sprocket/html/attributes.html#formaction"},{"doc":"sprocket/html/attributes","title":"height","content":"pub fn height(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.height\nsprocket/html/attributes height","url":"sprocket/html/attributes.html#height"},{"doc":"sprocket/html/attributes","title":"href","content":"pub fn href(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.href\nsprocket/html/attributes href","url":"sprocket/html/attributes.html#href"},{"doc":"sprocket/html/attributes","title":"http_equiv","content":"pub fn http_equiv(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.http_equiv\nsprocket/html/attributes http_equiv","url":"sprocket/html/attributes.html#http_equiv"},{"doc":"sprocket/html/attributes","title":"id","content":"pub fn id(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.id\nsprocket/html/attributes id","url":"sprocket/html/attributes.html#id"},{"doc":"sprocket/html/attributes","title":"input_type","content":"pub fn input_type(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.input_type\nsprocket/html/attributes input_type","url":"sprocket/html/attributes.html#input_type"},{"doc":"sprocket/html/attributes","title":"integrity","content":"pub fn integrity(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.integrity\nsprocket/html/attributes integrity","url":"sprocket/html/attributes.html#integrity"},{"doc":"sprocket/html/attributes","title":"lang","content":"pub fn lang(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.lang\nsprocket/html/attributes lang","url":"sprocket/html/attributes.html#lang"},{"doc":"sprocket/html/attributes","title":"loop","content":"pub fn loop() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.loop\nsprocket/html/attributes loop","url":"sprocket/html/attributes.html#loop"},{"doc":"sprocket/html/attributes","title":"media","content":"pub fn media(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.media\nsprocket/html/attributes media","url":"sprocket/html/attributes.html#media"},{"doc":"sprocket/html/attributes","title":"method","content":"pub fn method(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.method\nsprocket/html/attributes method","url":"sprocket/html/attributes.html#method"},{"doc":"sprocket/html/attributes","title":"name","content":"pub fn name(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.name\nsprocket/html/attributes name","url":"sprocket/html/attributes.html#name"},{"doc":"sprocket/html/attributes","title":"on_change","content":"pub fn on_change(identifiable_cb: IdentifiableCallback) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.on_change\nsprocket/html/attributes on_change","url":"sprocket/html/attributes.html#on_change"},{"doc":"sprocket/html/attributes","title":"on_click","content":"pub fn on_click(identifiable_cb: IdentifiableCallback) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.on_click\nsprocket/html/attributes on_click","url":"sprocket/html/attributes.html#on_click"},{"doc":"sprocket/html/attributes","title":"on_doubleclick","content":"pub fn on_doubleclick(identifiable_cb: IdentifiableCallback) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.on_doubleclick\nsprocket/html/attributes on_doubleclick","url":"sprocket/html/attributes.html#on_doubleclick"},{"doc":"sprocket/html/attributes","title":"on_input","content":"pub fn on_input(identifiable_cb: IdentifiableCallback) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.on_input\nsprocket/html/attributes on_input","url":"sprocket/html/attributes.html#on_input"},{"doc":"sprocket/html/attributes","title":"placeholder","content":"pub fn placeholder(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.placeholder\nsprocket/html/attributes placeholder","url":"sprocket/html/attributes.html#placeholder"},{"doc":"sprocket/html/attributes","title":"preload","content":"pub fn preload() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.preload\nsprocket/html/attributes preload","url":"sprocket/html/attributes.html#preload"},{"doc":"sprocket/html/attributes","title":"property","content":"pub fn property(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.property\nsprocket/html/attributes property","url":"sprocket/html/attributes.html#property"},{"doc":"sprocket/html/attributes","title":"readonly","content":"pub fn readonly() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.readonly\nsprocket/html/attributes readonly","url":"sprocket/html/attributes.html#readonly"},{"doc":"sprocket/html/attributes","title":"referrerpolicy","content":"pub fn referrerpolicy(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.referrerpolicy\nsprocket/html/attributes referrerpolicy","url":"sprocket/html/attributes.html#referrerpolicy"},{"doc":"sprocket/html/attributes","title":"rel","content":"pub fn rel(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.rel\nsprocket/html/attributes rel","url":"sprocket/html/attributes.html#rel"},{"doc":"sprocket/html/attributes","title":"role","content":"pub fn role(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.role\nsprocket/html/attributes role","url":"sprocket/html/attributes.html#role"},{"doc":"sprocket/html/attributes","title":"selected","content":"pub fn selected() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.selected\nsprocket/html/attributes selected","url":"sprocket/html/attributes.html#selected"},{"doc":"sprocket/html/attributes","title":"src","content":"pub fn src(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.src\nsprocket/html/attributes src","url":"sprocket/html/attributes.html#src"},{"doc":"sprocket/html/attributes","title":"style","content":"pub fn style(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.style\nsprocket/html/attributes style","url":"sprocket/html/attributes.html#style"},{"doc":"sprocket/html/attributes","title":"tabindex","content":"pub fn tabindex(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.tabindex\nsprocket/html/attributes tabindex","url":"sprocket/html/attributes.html#tabindex"},{"doc":"sprocket/html/attributes","title":"target","content":"pub fn target(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.target\nsprocket/html/attributes target","url":"sprocket/html/attributes.html#target"},{"doc":"sprocket/html/attributes","title":"title","content":"pub fn title(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.title\nsprocket/html/attributes title","url":"sprocket/html/attributes.html#title"},{"doc":"sprocket/html/attributes","title":"value","content":"pub fn value(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.value\nsprocket/html/attributes value","url":"sprocket/html/attributes.html#value"},{"doc":"sprocket/html/attributes","title":"width","content":"pub fn width(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.width\nsprocket/html/attributes width","url":"sprocket/html/attributes.html#width"},{"doc":"sprocket/html/attributes","title":"xmlns","content":"pub fn xmlns(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.xmlns\nsprocket/html/attributes xmlns","url":"sprocket/html/attributes.html#xmlns"},{"doc":"sprocket/html/attributes","title":"xmlns_xlink","content":"pub fn xmlns_xlink(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.xmlns_xlink\nsprocket/html/attributes xmlns_xlink","url":"sprocket/html/attributes.html#xmlns_xlink"},{"doc":"sprocket/html/attributes","title":"sprocket/html/attributes","content":"","url":"sprocket/html/attributes.html"},{"doc":"sprocket/hooks","title":"CallbackResult","content":"pub type CallbackResult {\n  CallbackResult(\n    callback: CallbackFn,\n    deps: Option(HookDependencies),\n  )\n}\n\nCallbackResult(\n  callback: CallbackFn,\n  deps: Option(HookDependencies),\n)\n\n\nSynonyms:\nsprocket/hooks.CallbackResult\nsprocket/hooks CallbackResult","url":"sprocket/hooks.html#CallbackResult"},{"doc":"sprocket/hooks","title":"ClientDispatcher","content":"pub type ClientDispatcher =\n  fn(String, Option(String)) -&gt; Result(Nil, Nil)\n\n\nSynonyms:\nsprocket/hooks.ClientDispatcher\nsprocket/hooks ClientDispatcher","url":"sprocket/hooks.html#ClientDispatcher"},{"doc":"sprocket/hooks","title":"ClientEventHandler","content":"pub type ClientEventHandler =\n  fn(String, Option(Dynamic), ClientDispatcher) -&gt; Nil\n\n\nSynonyms:\nsprocket/hooks.ClientEventHandler\nsprocket/hooks ClientEventHandler","url":"sprocket/hooks.html#ClientEventHandler"},{"doc":"sprocket/hooks","title":"Compared","content":"pub type Compared(a) {\n  Changed(changed: a)\n  Unchanged\n}\n\nChanged(changed: a)\n\n\nUnchanged\n\n\nSynonyms:\nsprocket/hooks.Compared\nsprocket/hooks Compared","url":"sprocket/hooks.html#Compared"},{"doc":"sprocket/hooks","title":"EffectCleanup","content":"pub type EffectCleanup =\n  Option(fn() -&gt; Nil)\n\n\nSynonyms:\nsprocket/hooks.EffectCleanup\nsprocket/hooks EffectCleanup","url":"sprocket/hooks.html#EffectCleanup"},{"doc":"sprocket/hooks","title":"EffectResult","content":"pub type EffectResult {\n  EffectResult(\n    cleanup: EffectCleanup,\n    deps: Option(HookDependencies),\n  )\n}\n\nEffectResult(\n  cleanup: EffectCleanup,\n  deps: Option(HookDependencies),\n)\n\n\nSynonyms:\nsprocket/hooks.EffectResult\nsprocket/hooks EffectResult","url":"sprocket/hooks.html#EffectResult"},{"doc":"sprocket/hooks","title":"Hook","content":"pub type Hook {\n  Callback(\n    id: Unique,\n    callback: CallbackFn,\n    trigger: HookTrigger,\n    prev: Option(CallbackResult),\n  )\n  Effect(\n    id: Unique,\n    effect: fn() -&gt; EffectCleanup,\n    trigger: HookTrigger,\n    prev: Option(EffectResult),\n  )\n  Reducer(id: Unique, reducer: Dynamic, cleanup: fn() -&gt; Nil)\n  State(id: Unique, value: Dynamic)\n  Client(\n    id: Unique,\n    name: String,\n    handle_event: Option(ClientEventHandler),\n  )\n}\n\nCallback(\n  id: Unique,\n  callback: CallbackFn,\n  trigger: HookTrigger,\n  prev: Option(CallbackResult),\n)\n\n\nEffect(\n  id: Unique,\n  effect: fn() -&gt; EffectCleanup,\n  trigger: HookTrigger,\n  prev: Option(EffectResult),\n)\n\n\nReducer(id: Unique, reducer: Dynamic, cleanup: fn() -&gt; Nil)\n\n\nState(id: Unique, value: Dynamic)\n\n\nClient(\n  id: Unique,\n  name: String,\n  handle_event: Option(ClientEventHandler),\n)\n\n\nSynonyms:\nsprocket/hooks.Hook\nsprocket/hooks Hook","url":"sprocket/hooks.html#Hook"},{"doc":"sprocket/hooks","title":"HookDependencies","content":"pub type HookDependencies =\n  List(Dynamic)\n\n\nSynonyms:\nsprocket/hooks.HookDependencies\nsprocket/hooks HookDependencies","url":"sprocket/hooks.html#HookDependencies"},{"doc":"sprocket/hooks","title":"HookTrigger","content":"pub type HookTrigger {\n  OnMount\n  OnUpdate\n  WithDeps(deps: HookDependencies)\n}\n\nOnMount\n\n\nOnUpdate\n\n\nWithDeps(deps: HookDependencies)\n\n\nSynonyms:\nsprocket/hooks.HookTrigger\nsprocket/hooks HookTrigger","url":"sprocket/hooks.html#HookTrigger"},{"doc":"sprocket/hooks","title":"compare_deps","content":"pub fn compare_deps(prev_deps: List(Dynamic), deps: List(Dynamic)) -&gt; Compared(\n  List(Dynamic),\n)\n\nSynonyms:\nsprocket/hooks.compare_deps\nsprocket/hooks compare_deps","url":"sprocket/hooks.html#compare_deps"},{"doc":"sprocket/hooks","title":"dep","content":"pub fn dep(dependency: a) -&gt; Dynamic\n\nSynonyms:\nsprocket/hooks.dep\nsprocket/hooks dep","url":"sprocket/hooks.html#dep"},{"doc":"sprocket/hooks","title":"sprocket/hooks","content":"","url":"sprocket/hooks.html"},{"doc":"sprocket/context","title":"AbstractFunctionalComponent","content":"pub type AbstractFunctionalComponent =\n  fn(Context, Dynamic) -&gt; #(Context, List(Element))\n\n\nSynonyms:\nsprocket/context.AbstractFunctionalComponent\nsprocket/context AbstractFunctionalComponent","url":"sprocket/context.html#AbstractFunctionalComponent"},{"doc":"sprocket/context","title":"ComponentHooks","content":"pub type ComponentHooks =\n  OrderedMap(Int, Hook)\n\n\nSynonyms:\nsprocket/context.ComponentHooks\nsprocket/context ComponentHooks","url":"sprocket/context.html#ComponentHooks"},{"doc":"sprocket/context","title":"ComponentWip","content":"pub type ComponentWip {\n  ComponentWip(\n    hooks: ComponentHooks,\n    index: Int,\n    is_first_render: Bool,\n  )\n}\n\nComponentWip(\n  hooks: ComponentHooks,\n  index: Int,\n  is_first_render: Bool,\n)\n\n\nSynonyms:\nsprocket/context.ComponentWip\nsprocket/context ComponentWip","url":"sprocket/context.html#ComponentWip"},{"doc":"sprocket/context","title":"Context","content":"pub type Context {\n  Context(\n    view: Element,\n    wip: ComponentWip,\n    handlers: List(EventHandler),\n    ws: Option(Unique),\n    render_update: fn() -&gt; Nil,\n    update_hook: fn(Unique, fn(Hook) -&gt; Hook) -&gt; Nil,\n    dispatch_event: fn(Unique, String, Option(String)) -&gt;\n      Result(Nil, Nil),\n  )\n}\n\nContext(\n  view: Element,\n  wip: ComponentWip,\n  handlers: List(EventHandler),\n  ws: Option(Unique),\n  render_update: fn() -&gt; Nil,\n  update_hook: fn(Unique, fn(Hook) -&gt; Hook) -&gt; Nil,\n  dispatch_event: fn(Unique, String, Option(String)) -&gt;\n    Result(Nil, Nil),\n)\n\n\nSynonyms:\nsprocket/context.Context\nsprocket/context Context","url":"sprocket/context.html#Context"},{"doc":"sprocket/context","title":"Dispatcher","content":"pub type Dispatcher {\n  Dispatcher(\n    dispatch: fn(String, String, Option(String)) -&gt;\n      Result(Nil, Nil),\n  )\n}\n\nDispatcher(\n  dispatch: fn(String, String, Option(String)) -&gt;\n    Result(Nil, Nil),\n)\n\n\nSynonyms:\nsprocket/context.Dispatcher\nsprocket/context Dispatcher","url":"sprocket/context.html#Dispatcher"},{"doc":"sprocket/context","title":"Element","content":"pub type Element {\n  Element(\n    tag: String,\n    attrs: List(Attribute),\n    children: List(Element),\n  )\n  Component(\n    component: FunctionalComponent(Dynamic),\n    props: Dynamic,\n  )\n  Debug(id: String, meta: Option(Dynamic), element: Element)\n  Keyed(key: String, element: Element)\n  IgnoreUpdate(element: Element)\n  SafeHtml(html: String)\n  Raw(text: String)\n}\n\nElement(\n  tag: String,\n  attrs: List(Attribute),\n  children: List(Element),\n)\n\n\nComponent(\n  component: FunctionalComponent(Dynamic),\n  props: Dynamic,\n)\n\n\nDebug(id: String, meta: Option(Dynamic), element: Element)\n\n\nKeyed(key: String, element: Element)\n\n\nIgnoreUpdate(element: Element)\n\n\nSafeHtml(html: String)\n\n\nRaw(text: String)\n\n\nSynonyms:\nsprocket/context.Element\nsprocket/context Element","url":"sprocket/context.html#Element"},{"doc":"sprocket/context","title":"EventHandler","content":"pub type EventHandler {\n  EventHandler(id: Unique, handler: CallbackFn)\n}\n\nEventHandler(id: Unique, handler: CallbackFn)\n\n\nSynonyms:\nsprocket/context.EventHandler\nsprocket/context EventHandler","url":"sprocket/context.html#EventHandler"},{"doc":"sprocket/context","title":"FunctionalComponent","content":"pub type FunctionalComponent(p) =\n  fn(Context, p) -&gt; #(Context, List(Element))\n\n\nSynonyms:\nsprocket/context.FunctionalComponent\nsprocket/context FunctionalComponent","url":"sprocket/context.html#FunctionalComponent"},{"doc":"sprocket/context","title":"Updater","content":"pub type Updater(r) {\n  Updater(send: fn(r) -&gt; Result(Nil, Nil))\n}\n\nUpdater(send: fn(r) -&gt; Result(Nil, Nil))\n\n\nSynonyms:\nsprocket/context.Updater\nsprocket/context Updater","url":"sprocket/context.html#Updater"},{"doc":"sprocket/context","title":"dispatch_event","content":"pub fn dispatch_event(ctx: Context, id: Unique, name: String, payload: Option(\n    String,\n  )) -&gt; Result(Nil, Nil)\n\nSynonyms:\nsprocket/context.dispatch_event\nsprocket/context dispatch_event","url":"sprocket/context.html#dispatch_event"},{"doc":"sprocket/context","title":"fetch_or_init_hook","content":"pub fn fetch_or_init_hook(ctx: Context, init: fn() -&gt; Hook) -&gt; #(\n  Context,\n  Hook,\n  Int,\n)\n\nSynonyms:\nsprocket/context.fetch_or_init_hook\nsprocket/context fetch_or_init_hook","url":"sprocket/context.html#fetch_or_init_hook"},{"doc":"sprocket/context","title":"get_event_handler","content":"pub fn get_event_handler(ctx: Context, id: Unique) -&gt; #(\n  Context,\n  Result(EventHandler, Nil),\n)\n\nSynonyms:\nsprocket/context.get_event_handler\nsprocket/context get_event_handler","url":"sprocket/context.html#get_event_handler"},{"doc":"sprocket/context","title":"new","content":"pub fn new(view: Element, ws: Option(Unique), dispatcher: Option(\n    Dispatcher,\n  )) -&gt; Context\n\nSynonyms:\nsprocket/context.new\nsprocket/context new","url":"sprocket/context.html#new"},{"doc":"sprocket/context","title":"push_event_handler","content":"pub fn push_event_handler(ctx: Context, identifiable_cb: IdentifiableCallback) -&gt; #(\n  Context,\n  Unique,\n)\n\nSynonyms:\nsprocket/context.push_event_handler\nsprocket/context push_event_handler","url":"sprocket/context.html#push_event_handler"},{"doc":"sprocket/context","title":"reset_for_render","content":"pub fn reset_for_render(ctx: Context) -&gt; Context\n\nSynonyms:\nsprocket/context.reset_for_render\nsprocket/context reset_for_render","url":"sprocket/context.html#reset_for_render"},{"doc":"sprocket/context","title":"update_hook","content":"pub fn update_hook(ctx: Context, hook: Hook, index: Int) -&gt; Context\n\nSynonyms:\nsprocket/context.update_hook\nsprocket/context update_hook","url":"sprocket/context.html#update_hook"},{"doc":"sprocket/context","title":"sprocket/context","content":"","url":"sprocket/context.html"},{"doc":"sprocket/hooks/callback","title":"callback","content":"pub fn callback(ctx: Context, callback_fn: CallbackFn, trigger: HookTrigger, cb: fn(\n    Context,\n    IdentifiableCallback,\n  ) -&gt; #(a, List(Element))) -&gt; #(a, List(Element))\n\nSynonyms:\nsprocket/hooks/callback.callback\nsprocket/hooks/callback callback","url":"sprocket/hooks/callback.html#callback"},{"doc":"sprocket/hooks/callback","title":"sprocket/hooks/callback","content":"","url":"sprocket/hooks/callback.html"},{"doc":"sprocket/html","title":"a","content":"pub fn a(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;a&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a)\nSynonyms:\nsprocket/html.a\nsprocket/html a","url":"sprocket/html.html#a"},{"doc":"sprocket/html","title":"a_text","content":"pub fn a_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.a(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.a_text\nsprocket/html a_text","url":"sprocket/html.html#a_text"},{"doc":"sprocket/html","title":"abbr","content":"pub fn abbr(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;abbr&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/abbr)\nSynonyms:\nsprocket/html.abbr\nsprocket/html abbr","url":"sprocket/html.html#abbr"},{"doc":"sprocket/html","title":"address","content":"pub fn address(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;address&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/address)\nSynonyms:\nsprocket/html.address\nsprocket/html address","url":"sprocket/html.html#address"},{"doc":"sprocket/html","title":"area","content":"pub fn area(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;area /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/area)\nSynonyms:\nsprocket/html.area\nsprocket/html area","url":"sprocket/html.html#area"},{"doc":"sprocket/html","title":"article","content":"pub fn article(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;article&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/article)\nSynonyms:\nsprocket/html.article\nsprocket/html article","url":"sprocket/html.html#article"},{"doc":"sprocket/html","title":"article_text","content":"pub fn article_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.article(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.article_text\nsprocket/html article_text","url":"sprocket/html.html#article_text"},{"doc":"sprocket/html","title":"aside","content":"pub fn aside(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;aside&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/aside)\nSynonyms:\nsprocket/html.aside\nsprocket/html aside","url":"sprocket/html.html#aside"},{"doc":"sprocket/html","title":"aside_text","content":"pub fn aside_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.aside(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.aside_text\nsprocket/html aside_text","url":"sprocket/html.html#aside_text"},{"doc":"sprocket/html","title":"audio","content":"pub fn audio(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;audio&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/audio)\nSynonyms:\nsprocket/html.audio\nsprocket/html audio","url":"sprocket/html.html#audio"},{"doc":"sprocket/html","title":"audio_text","content":"pub fn audio_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.audio(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.audio_text\nsprocket/html audio_text","url":"sprocket/html.html#audio_text"},{"doc":"sprocket/html","title":"b","content":"pub fn b(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;b&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/b)\nSynonyms:\nsprocket/html.b\nsprocket/html b","url":"sprocket/html.html#b"},{"doc":"sprocket/html","title":"b_text","content":"pub fn b_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.b(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.b_text\nsprocket/html b_text","url":"sprocket/html.html#b_text"},{"doc":"sprocket/html","title":"base","content":"pub fn base(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;base /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/base)\nSynonyms:\nsprocket/html.base\nsprocket/html base","url":"sprocket/html.html#base"},{"doc":"sprocket/html","title":"bdi","content":"pub fn bdi(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;bdi&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/bdi)\nSynonyms:\nsprocket/html.bdi\nsprocket/html bdi","url":"sprocket/html.html#bdi"},{"doc":"sprocket/html","title":"bdi_text","content":"pub fn bdi_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.bdi(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.bdi_text\nsprocket/html bdi_text","url":"sprocket/html.html#bdi_text"},{"doc":"sprocket/html","title":"bdo","content":"pub fn bdo(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;bdo&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/bdo)\nSynonyms:\nsprocket/html.bdo\nsprocket/html bdo","url":"sprocket/html.html#bdo"},{"doc":"sprocket/html","title":"bdo_text","content":"pub fn bdo_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.bdo(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.bdo_text\nsprocket/html bdo_text","url":"sprocket/html.html#bdo_text"},{"doc":"sprocket/html","title":"blockquote","content":"pub fn blockquote(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;blockquote&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/blockquote)\nSynonyms:\nsprocket/html.blockquote\nsprocket/html blockquote","url":"sprocket/html.html#blockquote"},{"doc":"sprocket/html","title":"blockquote_text","content":"pub fn blockquote_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.blockquote(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.blockquote_text\nsprocket/html blockquote_text","url":"sprocket/html.html#blockquote_text"},{"doc":"sprocket/html","title":"body","content":"pub fn body(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;body&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/body)\nSynonyms:\nsprocket/html.body\nsprocket/html body","url":"sprocket/html.html#body"},{"doc":"sprocket/html","title":"br","content":"pub fn br(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;br /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/br)\nSynonyms:\nsprocket/html.br\nsprocket/html br","url":"sprocket/html.html#br"},{"doc":"sprocket/html","title":"button","content":"pub fn button(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;button&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/button)\nSynonyms:\nsprocket/html.button\nsprocket/html button","url":"sprocket/html.html#button"},{"doc":"sprocket/html","title":"button_text","content":"pub fn button_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.button(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.button_text\nsprocket/html button_text","url":"sprocket/html.html#button_text"},{"doc":"sprocket/html","title":"canvas","content":"pub fn canvas(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;canvas&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/canvas)\nSynonyms:\nsprocket/html.canvas\nsprocket/html canvas","url":"sprocket/html.html#canvas"},{"doc":"sprocket/html","title":"canvas_text","content":"pub fn canvas_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.canvas(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.canvas_text\nsprocket/html canvas_text","url":"sprocket/html.html#canvas_text"},{"doc":"sprocket/html","title":"caption","content":"pub fn caption(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;caption&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/caption)\nSynonyms:\nsprocket/html.caption\nsprocket/html caption","url":"sprocket/html.html#caption"},{"doc":"sprocket/html","title":"caption_text","content":"pub fn caption_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.caption(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.caption_text\nsprocket/html caption_text","url":"sprocket/html.html#caption_text"},{"doc":"sprocket/html","title":"cite","content":"pub fn cite(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;cite&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/cite)\nSynonyms:\nsprocket/html.cite\nsprocket/html cite","url":"sprocket/html.html#cite"},{"doc":"sprocket/html","title":"cite_text","content":"pub fn cite_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.cite(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.cite_text\nsprocket/html cite_text","url":"sprocket/html.html#cite_text"},{"doc":"sprocket/html","title":"code","content":"pub fn code(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;code&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/code)\nSynonyms:\nsprocket/html.code\nsprocket/html code","url":"sprocket/html.html#code"},{"doc":"sprocket/html","title":"code_text","content":"pub fn code_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.code(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.code_text\nsprocket/html code_text","url":"sprocket/html.html#code_text"},{"doc":"sprocket/html","title":"col","content":"pub fn col(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;col&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/col)\nSynonyms:\nsprocket/html.col\nsprocket/html col","url":"sprocket/html.html#col"},{"doc":"sprocket/html","title":"col_text","content":"pub fn col_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.col(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.col_text\nsprocket/html col_text","url":"sprocket/html.html#col_text"},{"doc":"sprocket/html","title":"colgroup","content":"pub fn colgroup(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;colgroup&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/colgroup)\nSynonyms:\nsprocket/html.colgroup\nsprocket/html colgroup","url":"sprocket/html.html#colgroup"},{"doc":"sprocket/html","title":"colgroup_text","content":"pub fn colgroup_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.colgroup(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.colgroup_text\nsprocket/html colgroup_text","url":"sprocket/html.html#colgroup_text"},{"doc":"sprocket/html","title":"dangerous_raw_html","content":"pub fn dangerous_raw_html(html: String) -&gt; Element\n\nSynonyms:\nsprocket/html.dangerous_raw_html\nsprocket/html dangerous_raw_html","url":"sprocket/html.html#dangerous_raw_html"},{"doc":"sprocket/html","title":"data","content":"pub fn data(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;data&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/data)\nSynonyms:\nsprocket/html.data\nsprocket/html data","url":"sprocket/html.html#data"},{"doc":"sprocket/html","title":"data_text","content":"pub fn data_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.data(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.data_text\nsprocket/html data_text","url":"sprocket/html.html#data_text"},{"doc":"sprocket/html","title":"datalist","content":"pub fn datalist(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;datalist&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/datalist)\nSynonyms:\nsprocket/html.datalist\nsprocket/html datalist","url":"sprocket/html.html#datalist"},{"doc":"sprocket/html","title":"datalist_text","content":"pub fn datalist_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.datalist(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.datalist_text\nsprocket/html datalist_text","url":"sprocket/html.html#datalist_text"},{"doc":"sprocket/html","title":"dd","content":"pub fn dd(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;dd&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dd)\nSynonyms:\nsprocket/html.dd\nsprocket/html dd","url":"sprocket/html.html#dd"},{"doc":"sprocket/html","title":"dd_text","content":"pub fn dd_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.dd(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.dd_text\nsprocket/html dd_text","url":"sprocket/html.html#dd_text"},{"doc":"sprocket/html","title":"debug","content":"pub fn debug(id: String, meta: Option(Dynamic), element: Element) -&gt; Element\n\nSynonyms:\nsprocket/html.debug\nsprocket/html debug","url":"sprocket/html.html#debug"},{"doc":"sprocket/html","title":"del","content":"pub fn del(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;del&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/del)\nSynonyms:\nsprocket/html.del\nsprocket/html del","url":"sprocket/html.html#del"},{"doc":"sprocket/html","title":"del_text","content":"pub fn del_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.del(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.del_text\nsprocket/html del_text","url":"sprocket/html.html#del_text"},{"doc":"sprocket/html","title":"details","content":"pub fn details(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;details&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/details)\nSynonyms:\nsprocket/html.details\nsprocket/html details","url":"sprocket/html.html#details"},{"doc":"sprocket/html","title":"details_text","content":"pub fn details_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.details(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.details_text\nsprocket/html details_text","url":"sprocket/html.html#details_text"},{"doc":"sprocket/html","title":"dfn","content":"pub fn dfn(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;dfn&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dfn)\nSynonyms:\nsprocket/html.dfn\nsprocket/html dfn","url":"sprocket/html.html#dfn"},{"doc":"sprocket/html","title":"dfn_text","content":"pub fn dfn_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.dfn(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.dfn_text\nsprocket/html dfn_text","url":"sprocket/html.html#dfn_text"},{"doc":"sprocket/html","title":"dialog","content":"pub fn dialog(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;dialog&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dialog)\nSynonyms:\nsprocket/html.dialog\nsprocket/html dialog","url":"sprocket/html.html#dialog"},{"doc":"sprocket/html","title":"dialog_text","content":"pub fn dialog_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.dialog(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.dialog_text\nsprocket/html dialog_text","url":"sprocket/html.html#dialog_text"},{"doc":"sprocket/html","title":"div","content":"pub fn div(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;div&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/div)\nSynonyms:\nsprocket/html.div\nsprocket/html div","url":"sprocket/html.html#div"},{"doc":"sprocket/html","title":"div_text","content":"pub fn div_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.div(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.div_text\nsprocket/html div_text","url":"sprocket/html.html#div_text"},{"doc":"sprocket/html","title":"dl","content":"pub fn dl(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;dl&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dl)\nSynonyms:\nsprocket/html.dl\nsprocket/html dl","url":"sprocket/html.html#dl"},{"doc":"sprocket/html","title":"dl_text","content":"pub fn dl_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.dl(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.dl_text\nsprocket/html dl_text","url":"sprocket/html.html#dl_text"},{"doc":"sprocket/html","title":"dt","content":"pub fn dt(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;dt&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dt)\nSynonyms:\nsprocket/html.dt\nsprocket/html dt","url":"sprocket/html.html#dt"},{"doc":"sprocket/html","title":"dt_text","content":"pub fn dt_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.dt(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.dt_text\nsprocket/html dt_text","url":"sprocket/html.html#dt_text"},{"doc":"sprocket/html","title":"el","content":"pub fn el(tag: String, attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nsprocket/html.el\nsprocket/html el","url":"sprocket/html.html#el"},{"doc":"sprocket/html","title":"em","content":"pub fn em(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;em&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/em)\nSynonyms:\nsprocket/html.em\nsprocket/html em","url":"sprocket/html.html#em"},{"doc":"sprocket/html","title":"em_text","content":"pub fn em_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.em(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.em_text\nsprocket/html em_text","url":"sprocket/html.html#em_text"},{"doc":"sprocket/html","title":"embed","content":"pub fn embed(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;embed&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/embed)\nSynonyms:\nsprocket/html.embed\nsprocket/html embed","url":"sprocket/html.html#embed"},{"doc":"sprocket/html","title":"embed_text","content":"pub fn embed_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.embed(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.embed_text\nsprocket/html embed_text","url":"sprocket/html.html#embed_text"},{"doc":"sprocket/html","title":"fieldset","content":"pub fn fieldset(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;fieldset&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/fieldset)\nSynonyms:\nsprocket/html.fieldset\nsprocket/html fieldset","url":"sprocket/html.html#fieldset"},{"doc":"sprocket/html","title":"fieldset_text","content":"pub fn fieldset_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.fieldset(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.fieldset_text\nsprocket/html fieldset_text","url":"sprocket/html.html#fieldset_text"},{"doc":"sprocket/html","title":"figcaption","content":"pub fn figcaption(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;figcaption&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/figcaption)\nSynonyms:\nsprocket/html.figcaption\nsprocket/html figcaption","url":"sprocket/html.html#figcaption"},{"doc":"sprocket/html","title":"figcaption_text","content":"pub fn figcaption_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.figcaption(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.figcaption_text\nsprocket/html figcaption_text","url":"sprocket/html.html#figcaption_text"},{"doc":"sprocket/html","title":"figure","content":"pub fn figure(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;figure&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/figure)\nSynonyms:\nsprocket/html.figure\nsprocket/html figure","url":"sprocket/html.html#figure"},{"doc":"sprocket/html","title":"figure_text","content":"pub fn figure_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.figure(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.figure_text\nsprocket/html figure_text","url":"sprocket/html.html#figure_text"},{"doc":"sprocket/html","title":"footer","content":"pub fn footer(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;footer&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/footer)\nSynonyms:\nsprocket/html.footer\nsprocket/html footer","url":"sprocket/html.html#footer"},{"doc":"sprocket/html","title":"footer_text","content":"pub fn footer_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.footer(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.footer_text\nsprocket/html footer_text","url":"sprocket/html.html#footer_text"},{"doc":"sprocket/html","title":"form","content":"pub fn form(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;form&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form)\nSynonyms:\nsprocket/html.form\nsprocket/html form","url":"sprocket/html.html#form"},{"doc":"sprocket/html","title":"form_text","content":"pub fn form_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.form(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.form_text\nsprocket/html form_text","url":"sprocket/html.html#form_text"},{"doc":"sprocket/html","title":"h1","content":"pub fn h1(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;h1&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h1)\nSynonyms:\nsprocket/html.h1\nsprocket/html h1","url":"sprocket/html.html#h1"},{"doc":"sprocket/html","title":"h1_text","content":"pub fn h1_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.h1(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.h1_text\nsprocket/html h1_text","url":"sprocket/html.html#h1_text"},{"doc":"sprocket/html","title":"h2","content":"pub fn h2(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;h2&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h2)\nSynonyms:\nsprocket/html.h2\nsprocket/html h2","url":"sprocket/html.html#h2"},{"doc":"sprocket/html","title":"h2_text","content":"pub fn h2_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.h2(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.h2_text\nsprocket/html h2_text","url":"sprocket/html.html#h2_text"},{"doc":"sprocket/html","title":"h3","content":"pub fn h3(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;h3&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h3)\nSynonyms:\nsprocket/html.h3\nsprocket/html h3","url":"sprocket/html.html#h3"},{"doc":"sprocket/html","title":"h3_text","content":"pub fn h3_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.h3(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.h3_text\nsprocket/html h3_text","url":"sprocket/html.html#h3_text"},{"doc":"sprocket/html","title":"h4","content":"pub fn h4(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;h4&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h4)\nSynonyms:\nsprocket/html.h4\nsprocket/html h4","url":"sprocket/html.html#h4"},{"doc":"sprocket/html","title":"h4_text","content":"pub fn h4_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.h4(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.h4_text\nsprocket/html h4_text","url":"sprocket/html.html#h4_text"},{"doc":"sprocket/html","title":"h5","content":"pub fn h5(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;h5&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h5)\nSynonyms:\nsprocket/html.h5\nsprocket/html h5","url":"sprocket/html.html#h5"},{"doc":"sprocket/html","title":"h5_text","content":"pub fn h5_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.h5(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.h5_text\nsprocket/html h5_text","url":"sprocket/html.html#h5_text"},{"doc":"sprocket/html","title":"h6","content":"pub fn h6(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;h6&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h6)\nSynonyms:\nsprocket/html.h6\nsprocket/html h6","url":"sprocket/html.html#h6"},{"doc":"sprocket/html","title":"h6_text","content":"pub fn h6_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.h6(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.h6_text\nsprocket/html h6_text","url":"sprocket/html.html#h6_text"},{"doc":"sprocket/html","title":"head","content":"pub fn head(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;head&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/head)\nSynonyms:\nsprocket/html.head\nsprocket/html head","url":"sprocket/html.html#head"},{"doc":"sprocket/html","title":"header","content":"pub fn header(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;header&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/header)\nSynonyms:\nsprocket/html.header\nsprocket/html header","url":"sprocket/html.html#header"},{"doc":"sprocket/html","title":"header_text","content":"pub fn header_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.header(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.header_text\nsprocket/html header_text","url":"sprocket/html.html#header_text"},{"doc":"sprocket/html","title":"hr","content":"pub fn hr(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;hr /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/hr)\nSynonyms:\nsprocket/html.hr\nsprocket/html hr","url":"sprocket/html.html#hr"},{"doc":"sprocket/html","title":"html","content":"pub fn html(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;html&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/html)\nSynonyms:\nsprocket/html.html\nsprocket/html html","url":"sprocket/html.html#html"},{"doc":"sprocket/html","title":"i","content":"pub fn i(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;i&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/i)\nSynonyms:\nsprocket/html.i\nsprocket/html i","url":"sprocket/html.html#i"},{"doc":"sprocket/html","title":"i_text","content":"pub fn i_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.i(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.i_text\nsprocket/html i_text","url":"sprocket/html.html#i_text"},{"doc":"sprocket/html","title":"iframe","content":"pub fn iframe(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;iframe&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/iframe)\nSynonyms:\nsprocket/html.iframe\nsprocket/html iframe","url":"sprocket/html.html#iframe"},{"doc":"sprocket/html","title":"iframe_text","content":"pub fn iframe_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.iframe(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.iframe_text\nsprocket/html iframe_text","url":"sprocket/html.html#iframe_text"},{"doc":"sprocket/html","title":"ignored","content":"pub fn ignored(element: Element) -&gt; Element\n\nSynonyms:\nsprocket/html.ignored\nsprocket/html ignored","url":"sprocket/html.html#ignored"},{"doc":"sprocket/html","title":"img","content":"pub fn img(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;img /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/img)\nSynonyms:\nsprocket/html.img\nsprocket/html img","url":"sprocket/html.html#img"},{"doc":"sprocket/html","title":"input","content":"pub fn input(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;input /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input)\nSynonyms:\nsprocket/html.input\nsprocket/html input","url":"sprocket/html.html#input"},{"doc":"sprocket/html","title":"ins","content":"pub fn ins(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;ins&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/ins)\nSynonyms:\nsprocket/html.ins\nsprocket/html ins","url":"sprocket/html.html#ins"},{"doc":"sprocket/html","title":"ins_text","content":"pub fn ins_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.ins(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.ins_text\nsprocket/html ins_text","url":"sprocket/html.html#ins_text"},{"doc":"sprocket/html","title":"kbd","content":"pub fn kbd(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;kbd&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/kbd)\nSynonyms:\nsprocket/html.kbd\nsprocket/html kbd","url":"sprocket/html.html#kbd"},{"doc":"sprocket/html","title":"kbd_text","content":"pub fn kbd_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.kbd(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.kbd_text\nsprocket/html kbd_text","url":"sprocket/html.html#kbd_text"},{"doc":"sprocket/html","title":"keyed","content":"pub fn keyed(key: String, element: Element) -&gt; Element\n\nSynonyms:\nsprocket/html.keyed\nsprocket/html keyed","url":"sprocket/html.html#keyed"},{"doc":"sprocket/html","title":"label","content":"pub fn label(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;label&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/label)\nSynonyms:\nsprocket/html.label\nsprocket/html label","url":"sprocket/html.html#label"},{"doc":"sprocket/html","title":"label_text","content":"pub fn label_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.label(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.label_text\nsprocket/html label_text","url":"sprocket/html.html#label_text"},{"doc":"sprocket/html","title":"legend","content":"pub fn legend(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;legend&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/legend)\nSynonyms:\nsprocket/html.legend\nsprocket/html legend","url":"sprocket/html.html#legend"},{"doc":"sprocket/html","title":"legend_text","content":"pub fn legend_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.legend(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.legend_text\nsprocket/html legend_text","url":"sprocket/html.html#legend_text"},{"doc":"sprocket/html","title":"li","content":"pub fn li(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;li&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/li)\nSynonyms:\nsprocket/html.li\nsprocket/html li","url":"sprocket/html.html#li"},{"doc":"sprocket/html","title":"li_text","content":"pub fn li_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.li(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.li_text\nsprocket/html li_text","url":"sprocket/html.html#li_text"},{"doc":"sprocket/html","title":"link","content":"pub fn link(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;link /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/link)\nSynonyms:\nsprocket/html.link\nsprocket/html link","url":"sprocket/html.html#link"},{"doc":"sprocket/html","title":"main","content":"pub fn main(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;main&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/main)\nSynonyms:\nsprocket/html.main\nsprocket/html main","url":"sprocket/html.html#main"},{"doc":"sprocket/html","title":"main_text","content":"pub fn main_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.main(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.main_text\nsprocket/html main_text","url":"sprocket/html.html#main_text"},{"doc":"sprocket/html","title":"map","content":"pub fn map(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;map&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/map)\nSynonyms:\nsprocket/html.map\nsprocket/html map","url":"sprocket/html.html#map"},{"doc":"sprocket/html","title":"map_text","content":"pub fn map_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.map(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.map_text\nsprocket/html map_text","url":"sprocket/html.html#map_text"},{"doc":"sprocket/html","title":"mark","content":"pub fn mark(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;mark&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/mark)\nSynonyms:\nsprocket/html.mark\nsprocket/html mark","url":"sprocket/html.html#mark"},{"doc":"sprocket/html","title":"mark_text","content":"pub fn mark_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.mark(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.mark_text\nsprocket/html mark_text","url":"sprocket/html.html#mark_text"},{"doc":"sprocket/html","title":"math","content":"pub fn math(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;math&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/math)\nSynonyms:\nsprocket/html.math\nsprocket/html math","url":"sprocket/html.html#math"},{"doc":"sprocket/html","title":"math_text","content":"pub fn math_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.math(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.math_text\nsprocket/html math_text","url":"sprocket/html.html#math_text"},{"doc":"sprocket/html","title":"menu","content":"pub fn menu(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;menu&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/menu)\nSynonyms:\nsprocket/html.menu\nsprocket/html menu","url":"sprocket/html.html#menu"},{"doc":"sprocket/html","title":"menu_text","content":"pub fn menu_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.menu(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.menu_text\nsprocket/html menu_text","url":"sprocket/html.html#menu_text"},{"doc":"sprocket/html","title":"menuitem","content":"pub fn menuitem(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;menuitem&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/menuitem)\nSynonyms:\nsprocket/html.menuitem\nsprocket/html menuitem","url":"sprocket/html.html#menuitem"},{"doc":"sprocket/html","title":"menuitem_text","content":"pub fn menuitem_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.menuitem(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.menuitem_text\nsprocket/html menuitem_text","url":"sprocket/html.html#menuitem_text"},{"doc":"sprocket/html","title":"meta","content":"pub fn meta(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;meta /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/meta)\nSynonyms:\nsprocket/html.meta\nsprocket/html meta","url":"sprocket/html.html#meta"},{"doc":"sprocket/html","title":"meter","content":"pub fn meter(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;meter&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/meter)\nSynonyms:\nsprocket/html.meter\nsprocket/html meter","url":"sprocket/html.html#meter"},{"doc":"sprocket/html","title":"meter_text","content":"pub fn meter_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.meter(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.meter_text\nsprocket/html meter_text","url":"sprocket/html.html#meter_text"},{"doc":"sprocket/html","title":"nav","content":"pub fn nav(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;nav&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/nav)\nSynonyms:\nsprocket/html.nav\nsprocket/html nav","url":"sprocket/html.html#nav"},{"doc":"sprocket/html","title":"nav_text","content":"pub fn nav_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.nav(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.nav_text\nsprocket/html nav_text","url":"sprocket/html.html#nav_text"},{"doc":"sprocket/html","title":"noscript","content":"pub fn noscript(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;noscript&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/noscript)\nSynonyms:\nsprocket/html.noscript\nsprocket/html noscript","url":"sprocket/html.html#noscript"},{"doc":"sprocket/html","title":"noscript_text","content":"pub fn noscript_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.noscript(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.noscript_text\nsprocket/html noscript_text","url":"sprocket/html.html#noscript_text"},{"doc":"sprocket/html","title":"object","content":"pub fn object(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;object&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/object)\nSynonyms:\nsprocket/html.object\nsprocket/html object","url":"sprocket/html.html#object"},{"doc":"sprocket/html","title":"object_text","content":"pub fn object_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.object(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.object_text\nsprocket/html object_text","url":"sprocket/html.html#object_text"},{"doc":"sprocket/html","title":"ol","content":"pub fn ol(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;ol&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/ol)\nSynonyms:\nsprocket/html.ol\nsprocket/html ol","url":"sprocket/html.html#ol"},{"doc":"sprocket/html","title":"ol_text","content":"pub fn ol_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.ol(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.ol_text\nsprocket/html ol_text","url":"sprocket/html.html#ol_text"},{"doc":"sprocket/html","title":"optgroup","content":"pub fn optgroup(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;optgroup&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/optgroup)\nSynonyms:\nsprocket/html.optgroup\nsprocket/html optgroup","url":"sprocket/html.html#optgroup"},{"doc":"sprocket/html","title":"optgroup_text","content":"pub fn optgroup_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.optgroup(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.optgroup_text\nsprocket/html optgroup_text","url":"sprocket/html.html#optgroup_text"},{"doc":"sprocket/html","title":"option","content":"pub fn option(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;option&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/option)\nSynonyms:\nsprocket/html.option\nsprocket/html option","url":"sprocket/html.html#option"},{"doc":"sprocket/html","title":"option_text","content":"pub fn option_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.option(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.option_text\nsprocket/html option_text","url":"sprocket/html.html#option_text"},{"doc":"sprocket/html","title":"output","content":"pub fn output(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;output&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/output)\nSynonyms:\nsprocket/html.output\nsprocket/html output","url":"sprocket/html.html#output"},{"doc":"sprocket/html","title":"output_text","content":"pub fn output_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.output(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.output_text\nsprocket/html output_text","url":"sprocket/html.html#output_text"},{"doc":"sprocket/html","title":"p","content":"pub fn p(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;p&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/p)\nSynonyms:\nsprocket/html.p\nsprocket/html p","url":"sprocket/html.html#p"},{"doc":"sprocket/html","title":"p_text","content":"pub fn p_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.p(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.p_text\nsprocket/html p_text","url":"sprocket/html.html#p_text"},{"doc":"sprocket/html","title":"param","content":"pub fn param(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;param&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/param)\nSynonyms:\nsprocket/html.param\nsprocket/html param","url":"sprocket/html.html#param"},{"doc":"sprocket/html","title":"param_text","content":"pub fn param_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.param(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.param_text\nsprocket/html param_text","url":"sprocket/html.html#param_text"},{"doc":"sprocket/html","title":"picture","content":"pub fn picture(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;picture&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/picture)\nSynonyms:\nsprocket/html.picture\nsprocket/html picture","url":"sprocket/html.html#picture"},{"doc":"sprocket/html","title":"picture_text","content":"pub fn picture_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.picture(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.picture_text\nsprocket/html picture_text","url":"sprocket/html.html#picture_text"},{"doc":"sprocket/html","title":"pre","content":"pub fn pre(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;pre&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/pre)\nSynonyms:\nsprocket/html.pre\nsprocket/html pre","url":"sprocket/html.html#pre"},{"doc":"sprocket/html","title":"pre_text","content":"pub fn pre_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.pre(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.pre_text\nsprocket/html pre_text","url":"sprocket/html.html#pre_text"},{"doc":"sprocket/html","title":"progress","content":"pub fn progress(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;progress&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/progress)\nSynonyms:\nsprocket/html.progress\nsprocket/html progress","url":"sprocket/html.html#progress"},{"doc":"sprocket/html","title":"progress_text","content":"pub fn progress_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.progress(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.progress_text\nsprocket/html progress_text","url":"sprocket/html.html#progress_text"},{"doc":"sprocket/html","title":"q","content":"pub fn q(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;q&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/q)\nSynonyms:\nsprocket/html.q\nsprocket/html q","url":"sprocket/html.html#q"},{"doc":"sprocket/html","title":"q_text","content":"pub fn q_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.q(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.q_text\nsprocket/html q_text","url":"sprocket/html.html#q_text"},{"doc":"sprocket/html","title":"rp","content":"pub fn rp(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;rp&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/rp)\nSynonyms:\nsprocket/html.rp\nsprocket/html rp","url":"sprocket/html.html#rp"},{"doc":"sprocket/html","title":"rp_text","content":"pub fn rp_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.rp(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.rp_text\nsprocket/html rp_text","url":"sprocket/html.html#rp_text"},{"doc":"sprocket/html","title":"rt","content":"pub fn rt(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;rt&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/rt)\nSynonyms:\nsprocket/html.rt\nsprocket/html rt","url":"sprocket/html.html#rt"},{"doc":"sprocket/html","title":"rt_text","content":"pub fn rt_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.rt(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.rt_text\nsprocket/html rt_text","url":"sprocket/html.html#rt_text"},{"doc":"sprocket/html","title":"ruby","content":"pub fn ruby(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;ruby&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/ruby)\nSynonyms:\nsprocket/html.ruby\nsprocket/html ruby","url":"sprocket/html.html#ruby"},{"doc":"sprocket/html","title":"ruby_text","content":"pub fn ruby_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.ruby(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.ruby_text\nsprocket/html ruby_text","url":"sprocket/html.html#ruby_text"},{"doc":"sprocket/html","title":"s","content":"pub fn s(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;s&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/s)\nSynonyms:\nsprocket/html.s\nsprocket/html s","url":"sprocket/html.html#s"},{"doc":"sprocket/html","title":"s_text","content":"pub fn s_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.s(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.s_text\nsprocket/html s_text","url":"sprocket/html.html#s_text"},{"doc":"sprocket/html","title":"samp","content":"pub fn samp(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;samp&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/samp)\nSynonyms:\nsprocket/html.samp\nsprocket/html samp","url":"sprocket/html.html#samp"},{"doc":"sprocket/html","title":"samp_text","content":"pub fn samp_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.samp(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.samp_text\nsprocket/html samp_text","url":"sprocket/html.html#samp_text"},{"doc":"sprocket/html","title":"script","content":"pub fn script(attrs: List(Attribute), body: Option(String)) -&gt; Element\n The [HTML `&lt;script&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/script)\nSynonyms:\nsprocket/html.script\nsprocket/html script","url":"sprocket/html.html#script"},{"doc":"sprocket/html","title":"section","content":"pub fn section(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;section&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/section)\nSynonyms:\nsprocket/html.section\nsprocket/html section","url":"sprocket/html.html#section"},{"doc":"sprocket/html","title":"section_text","content":"pub fn section_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.section(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.section_text\nsprocket/html section_text","url":"sprocket/html.html#section_text"},{"doc":"sprocket/html","title":"select","content":"pub fn select(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;select&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/select)\nSynonyms:\nsprocket/html.select\nsprocket/html select","url":"sprocket/html.html#select"},{"doc":"sprocket/html","title":"select_text","content":"pub fn select_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.select(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.select_text\nsprocket/html select_text","url":"sprocket/html.html#select_text"},{"doc":"sprocket/html","title":"small","content":"pub fn small(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;small&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/small)\nSynonyms:\nsprocket/html.small\nsprocket/html small","url":"sprocket/html.html#small"},{"doc":"sprocket/html","title":"small_text","content":"pub fn small_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.small(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.small_text\nsprocket/html small_text","url":"sprocket/html.html#small_text"},{"doc":"sprocket/html","title":"source","content":"pub fn source(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;source /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/source)\nSynonyms:\nsprocket/html.source\nsprocket/html source","url":"sprocket/html.html#source"},{"doc":"sprocket/html","title":"span","content":"pub fn span(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;span&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/span)\nSynonyms:\nsprocket/html.span\nsprocket/html span","url":"sprocket/html.html#span"},{"doc":"sprocket/html","title":"span_text","content":"pub fn span_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.span(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.span_text\nsprocket/html span_text","url":"sprocket/html.html#span_text"},{"doc":"sprocket/html","title":"strong","content":"pub fn strong(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;strong&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/strong)\nSynonyms:\nsprocket/html.strong\nsprocket/html strong","url":"sprocket/html.html#strong"},{"doc":"sprocket/html","title":"strong_text","content":"pub fn strong_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.strong(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.strong_text\nsprocket/html strong_text","url":"sprocket/html.html#strong_text"},{"doc":"sprocket/html","title":"sub","content":"pub fn sub(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;sub&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/sub)\nSynonyms:\nsprocket/html.sub\nsprocket/html sub","url":"sprocket/html.html#sub"},{"doc":"sprocket/html","title":"sub_text","content":"pub fn sub_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.sub(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.sub_text\nsprocket/html sub_text","url":"sprocket/html.html#sub_text"},{"doc":"sprocket/html","title":"summary","content":"pub fn summary(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;summary&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/summary)\nSynonyms:\nsprocket/html.summary\nsprocket/html summary","url":"sprocket/html.html#summary"},{"doc":"sprocket/html","title":"summary_text","content":"pub fn summary_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.summary(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.summary_text\nsprocket/html summary_text","url":"sprocket/html.html#summary_text"},{"doc":"sprocket/html","title":"sup","content":"pub fn sup(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;sup&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/sup)\nSynonyms:\nsprocket/html.sup\nsprocket/html sup","url":"sprocket/html.html#sup"},{"doc":"sprocket/html","title":"sup_text","content":"pub fn sup_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.sup(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.sup_text\nsprocket/html sup_text","url":"sprocket/html.html#sup_text"},{"doc":"sprocket/html","title":"svg","content":"pub fn svg(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;svg&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/svg)\nSynonyms:\nsprocket/html.svg\nsprocket/html svg","url":"sprocket/html.html#svg"},{"doc":"sprocket/html","title":"svg_text","content":"pub fn svg_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.svg(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.svg_text\nsprocket/html svg_text","url":"sprocket/html.html#svg_text"},{"doc":"sprocket/html","title":"table","content":"pub fn table(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;table&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/table)\nSynonyms:\nsprocket/html.table\nsprocket/html table","url":"sprocket/html.html#table"},{"doc":"sprocket/html","title":"table_text","content":"pub fn table_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.table(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.table_text\nsprocket/html table_text","url":"sprocket/html.html#table_text"},{"doc":"sprocket/html","title":"tbody","content":"pub fn tbody(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;tbody&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/tbody)\nSynonyms:\nsprocket/html.tbody\nsprocket/html tbody","url":"sprocket/html.html#tbody"},{"doc":"sprocket/html","title":"tbody_text","content":"pub fn tbody_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.tbody(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.tbody_text\nsprocket/html tbody_text","url":"sprocket/html.html#tbody_text"},{"doc":"sprocket/html","title":"td","content":"pub fn td(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;td&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/td)\nSynonyms:\nsprocket/html.td\nsprocket/html td","url":"sprocket/html.html#td"},{"doc":"sprocket/html","title":"td_text","content":"pub fn td_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.td(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.td_text\nsprocket/html td_text","url":"sprocket/html.html#td_text"},{"doc":"sprocket/html","title":"text","content":"pub fn text(text: String) -&gt; Element\n\nSynonyms:\nsprocket/html.text\nsprocket/html text","url":"sprocket/html.html#text"},{"doc":"sprocket/html","title":"textarea","content":"pub fn textarea(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;textarea&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/textarea)\nSynonyms:\nsprocket/html.textarea\nsprocket/html textarea","url":"sprocket/html.html#textarea"},{"doc":"sprocket/html","title":"textarea_text","content":"pub fn textarea_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.textarea(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.textarea_text\nsprocket/html textarea_text","url":"sprocket/html.html#textarea_text"},{"doc":"sprocket/html","title":"tfoot","content":"pub fn tfoot(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;tfoot&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/tfoot)\nSynonyms:\nsprocket/html.tfoot\nsprocket/html tfoot","url":"sprocket/html.html#tfoot"},{"doc":"sprocket/html","title":"tfoot_text","content":"pub fn tfoot_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.tfoot(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.tfoot_text\nsprocket/html tfoot_text","url":"sprocket/html.html#tfoot_text"},{"doc":"sprocket/html","title":"th","content":"pub fn th(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;th&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/th)\nSynonyms:\nsprocket/html.th\nsprocket/html th","url":"sprocket/html.html#th"},{"doc":"sprocket/html","title":"th_text","content":"pub fn th_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.th(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.th_text\nsprocket/html th_text","url":"sprocket/html.html#th_text"},{"doc":"sprocket/html","title":"thead","content":"pub fn thead(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;thead&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/thead)\nSynonyms:\nsprocket/html.thead\nsprocket/html thead","url":"sprocket/html.html#thead"},{"doc":"sprocket/html","title":"thead_text","content":"pub fn thead_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.thead(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.thead_text\nsprocket/html thead_text","url":"sprocket/html.html#thead_text"},{"doc":"sprocket/html","title":"time","content":"pub fn time(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;time&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/time)\nSynonyms:\nsprocket/html.time\nsprocket/html time","url":"sprocket/html.html#time"},{"doc":"sprocket/html","title":"time_text","content":"pub fn time_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.time(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.time_text\nsprocket/html time_text","url":"sprocket/html.html#time_text"},{"doc":"sprocket/html","title":"title","content":"pub fn title(title: String) -&gt; Element\n The HTML [`&lt;title&gt;`](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/title) element\nSynonyms:\nsprocket/html.title\nsprocket/html title","url":"sprocket/html.html#title"},{"doc":"sprocket/html","title":"tr","content":"pub fn tr(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;tr&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/tr)\nSynonyms:\nsprocket/html.tr\nsprocket/html tr","url":"sprocket/html.html#tr"},{"doc":"sprocket/html","title":"tr_text","content":"pub fn tr_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.tr(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.tr_text\nsprocket/html tr_text","url":"sprocket/html.html#tr_text"},{"doc":"sprocket/html","title":"track","content":"pub fn track(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;track /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/track)\nSynonyms:\nsprocket/html.track\nsprocket/html track","url":"sprocket/html.html#track"},{"doc":"sprocket/html","title":"u","content":"pub fn u(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;u&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/u)\nSynonyms:\nsprocket/html.u\nsprocket/html u","url":"sprocket/html.html#u"},{"doc":"sprocket/html","title":"u_text","content":"pub fn u_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.u(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.u_text\nsprocket/html u_text","url":"sprocket/html.html#u_text"},{"doc":"sprocket/html","title":"ul","content":"pub fn ul(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;ul&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/ul)\nSynonyms:\nsprocket/html.ul\nsprocket/html ul","url":"sprocket/html.html#ul"},{"doc":"sprocket/html","title":"ul_text","content":"pub fn ul_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.ul(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.ul_text\nsprocket/html ul_text","url":"sprocket/html.html#ul_text"},{"doc":"sprocket/html","title":"var","content":"pub fn var(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;var&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/var)\nSynonyms:\nsprocket/html.var\nsprocket/html var","url":"sprocket/html.html#var"},{"doc":"sprocket/html","title":"var_text","content":"pub fn var_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.var(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.var_text\nsprocket/html var_text","url":"sprocket/html.html#var_text"},{"doc":"sprocket/html","title":"video","content":"pub fn video(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;video&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/video)\nSynonyms:\nsprocket/html.video\nsprocket/html video","url":"sprocket/html.html#video"},{"doc":"sprocket/html","title":"video_text","content":"pub fn video_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.video(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.video_text\nsprocket/html video_text","url":"sprocket/html.html#video_text"},{"doc":"sprocket/html","title":"wbr","content":"pub fn wbr(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;wbr&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/wbr)\nSynonyms:\nsprocket/html.wbr\nsprocket/html wbr","url":"sprocket/html.html#wbr"},{"doc":"sprocket/html","title":"wbr_text","content":"pub fn wbr_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.wbr(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.wbr_text\nsprocket/html wbr_text","url":"sprocket/html.html#wbr_text"},{"doc":"sprocket/html","title":"sprocket/html","content":"","url":"sprocket/html.html"},{"doc":"sprocket/render","title":"RenderResult","content":"pub type RenderResult(a) {\n  RenderResult(ctx: Context, rendered: a)\n}\n\nRenderResult(ctx: Context, rendered: a)\n\n\nSynonyms:\nsprocket/render.RenderResult\nsprocket/render RenderResult","url":"sprocket/render.html#RenderResult"},{"doc":"sprocket/render","title":"RenderedAttribute","content":"pub type RenderedAttribute {\n  RenderedAttribute(name: String, value: String)\n  RenderedEventHandler(kind: String, id: String)\n  RenderedClientHook(name: String, id: String)\n}\n\nRenderedAttribute(name: String, value: String)\n\n\nRenderedEventHandler(kind: String, id: String)\n\n\nRenderedClientHook(name: String, id: String)\n\n\nSynonyms:\nsprocket/render.RenderedAttribute\nsprocket/render RenderedAttribute","url":"sprocket/render.html#RenderedAttribute"},{"doc":"sprocket/render","title":"RenderedElement","content":"pub type RenderedElement {\n  RenderedElement(\n    tag: String,\n    key: Option(String),\n    attrs: List(RenderedAttribute),\n    children: List(RenderedElement),\n  )\n  RenderedComponent(\n    fc: AbstractFunctionalComponent,\n    key: Option(String),\n    props: Dynamic,\n    hooks: ComponentHooks,\n    children: List(RenderedElement),\n  )\n  RenderedText(text: String)\n}\n\nRenderedElement(\n  tag: String,\n  key: Option(String),\n  attrs: List(RenderedAttribute),\n  children: List(RenderedElement),\n)\n\n\nRenderedComponent(\n  fc: AbstractFunctionalComponent,\n  key: Option(String),\n  props: Dynamic,\n  hooks: ComponentHooks,\n  children: List(RenderedElement),\n)\n\n\nRenderedText(text: String)\n\n\nSynonyms:\nsprocket/render.RenderedElement\nsprocket/render RenderedElement","url":"sprocket/render.html#RenderedElement"},{"doc":"sprocket/render","title":"Renderer","content":"pub type Renderer(result) {\n  Renderer(render: fn(RenderedElement) -&gt; result)\n}\n\nRenderer(render: fn(RenderedElement) -&gt; result)\n\n\nSynonyms:\nsprocket/render.Renderer\nsprocket/render Renderer","url":"sprocket/render.html#Renderer"},{"doc":"sprocket/render","title":"append_attribute","content":"pub fn append_attribute(el: RenderedElement, attr: RenderedAttribute) -&gt; RenderedElement\n\nSynonyms:\nsprocket/render.append_attribute\nsprocket/render append_attribute","url":"sprocket/render.html#append_attribute"},{"doc":"sprocket/render","title":"find","content":"pub fn find(el: RenderedElement, matches: fn(RenderedElement) -&gt;\n    Bool) -&gt; Result(RenderedElement, Nil)\n\nSynonyms:\nsprocket/render.find\nsprocket/render find","url":"sprocket/render.html#find"},{"doc":"sprocket/render","title":"live_render","content":"pub fn live_render(ctx: Context, el: Element, key: Option(String), prev: Option(\n    RenderedElement,\n  )) -&gt; RenderResult(RenderedElement)\n\nSynonyms:\nsprocket/render.live_render\nsprocket/render live_render","url":"sprocket/render.html#live_render"},{"doc":"sprocket/render","title":"render","content":"pub fn render(el: Element, renderer: Renderer(a)) -&gt; a\n\nSynonyms:\nsprocket/render.render\nsprocket/render render","url":"sprocket/render.html#render"},{"doc":"sprocket/render","title":"render_element","content":"pub fn render_element(el: Element) -&gt; RenderedElement\n Renders the given element into a stateless RenderedElement tree.\nSynonyms:\nsprocket/render.render_element\nsprocket/render render_element","url":"sprocket/render.html#render_element"},{"doc":"sprocket/render","title":"traverse","content":"pub fn traverse(el: RenderedElement, updater: fn(RenderedElement) -&gt;\n    RenderedElement) -&gt; RenderedElement\n\nSynonyms:\nsprocket/render.traverse\nsprocket/render traverse","url":"sprocket/render.html#traverse"},{"doc":"sprocket/render","title":"sprocket/render","content":"","url":"sprocket/render.html"},{"doc":"sprocket/sprocket","title":"Message","content":"pub type Message {\n  Shutdown\n  SetSelf(Sprocket)\n  BeginSelfDestruct(Int)\n  CancelSelfDestruct\n  GetRendered(reply_with: Subject(Option(RenderedElement)))\n  HasWebSocket(reply_with: Subject(Bool), ws: Unique)\n  SetRenderUpdate(fn() -&gt; Nil)\n  Render(reply_with: Subject(RenderedElement))\n  RenderUpdate\n  SetUpdateHook(fn(Unique, fn(Hook) -&gt; Hook) -&gt; Nil)\n  UpdateHook(Unique, fn(Hook) -&gt; Hook)\n  GetEventHandler(\n    reply_with: Subject(Result(EventHandler, Nil)),\n    id: Unique,\n  )\n  GetClientHook(\n    reply_with: Subject(Result(Hook, Nil)),\n    id: Unique,\n  )\n}\n\nShutdown\n\n\nSetSelf(Sprocket)\n\n\nBeginSelfDestruct(Int)\n\n\nCancelSelfDestruct\n\n\nGetRendered(reply_with: Subject(Option(RenderedElement)))\n\n\nHasWebSocket(reply_with: Subject(Bool), ws: Unique)\n\n\nSetRenderUpdate(fn() -&gt; Nil)\n\n\nRender(reply_with: Subject(RenderedElement))\n\n\nRenderUpdate\n\n\nSetUpdateHook(fn(Unique, fn(Hook) -&gt; Hook) -&gt; Nil)\n\n\nUpdateHook(Unique, fn(Hook) -&gt; Hook)\n\n\nGetEventHandler(\n  reply_with: Subject(Result(EventHandler, Nil)),\n  id: Unique,\n)\n\n\nGetClientHook(reply_with: Subject(Result(Hook, Nil)), id: Unique)\n\n\nSynonyms:\nsprocket/sprocket.Message\nsprocket/sprocket Message","url":"sprocket/sprocket.html#Message"},{"doc":"sprocket/sprocket","title":"Sprocket","content":"pub type Sprocket =\n  Subject(Message)\n\n\nSynonyms:\nsprocket/sprocket.Sprocket\nsprocket/sprocket Sprocket","url":"sprocket/sprocket.html#Sprocket"},{"doc":"sprocket/sprocket","title":"get_client_hook","content":"pub fn get_client_hook(actor: Subject(Message), id: String) -&gt; Result(\n  Hook,\n  Nil,\n)\n Get the client hook for a given id\nSynonyms:\nsprocket/sprocket.get_client_hook\nsprocket/sprocket get_client_hook","url":"sprocket/sprocket.html#get_client_hook"},{"doc":"sprocket/sprocket","title":"get_handler","content":"pub fn get_handler(actor: Subject(Message), id: String) -&gt; Result(\n  EventHandler,\n  Nil,\n)\n Get the event handler for a given id\nSynonyms:\nsprocket/sprocket.get_handler\nsprocket/sprocket get_handler","url":"sprocket/sprocket.html#get_handler"},{"doc":"sprocket/sprocket","title":"get_rendered","content":"pub fn get_rendered(actor: Subject(Message)) -&gt; Option(\n  RenderedElement,\n)\n Get the previously rendered view from the actor\nSynonyms:\nsprocket/sprocket.get_rendered\nsprocket/sprocket get_rendered","url":"sprocket/sprocket.html#get_rendered"},{"doc":"sprocket/sprocket","title":"has_websocket","content":"pub fn has_websocket(actor: Subject(Message), websocket: Unique) -&gt; Bool\n Returns true if the actor matches a given websocket connection\nSynonyms:\nsprocket/sprocket.has_websocket\nsprocket/sprocket has_websocket","url":"sprocket/sprocket.html#has_websocket"},{"doc":"sprocket/sprocket","title":"render","content":"pub fn render(actor: Subject(Message)) -&gt; RenderedElement\n Render the view\nSynonyms:\nsprocket/sprocket.render\nsprocket/sprocket render","url":"sprocket/sprocket.html#render"},{"doc":"sprocket/sprocket","title":"render_update","content":"pub fn render_update(actor: Subject(Message)) -&gt; Nil\n Render the view and send an update Patch to the updater\nSynonyms:\nsprocket/sprocket.render_update\nsprocket/sprocket render_update","url":"sprocket/sprocket.html#render_update"},{"doc":"sprocket/sprocket","title":"start","content":"pub fn start(view: Element, ws: Option(Unique), updater: Option(\n    Updater(Patch),\n  ), dispatcher: Option(Dispatcher)) -&gt; Subject(Message)\n Start a new sprocket actor\nSynonyms:\nsprocket/sprocket.start\nsprocket/sprocket start","url":"sprocket/sprocket.html#start"},{"doc":"sprocket/sprocket","title":"stop","content":"pub fn stop(actor: Subject(Message)) -&gt; Nil\n Stop a sprocket actor\nSynonyms:\nsprocket/sprocket.stop\nsprocket/sprocket stop","url":"sprocket/sprocket.html#stop"},{"doc":"sprocket/sprocket","title":"sprocket/sprocket","content":"","url":"sprocket/sprocket.html"},{"doc":"sprocket/cassette","title":"Cassette","content":"pub type Cassette =\n  Subject(Message)\n\n\nSynonyms:\nsprocket/cassette.Cassette\nsprocket/cassette Cassette","url":"sprocket/cassette.html#Cassette"},{"doc":"sprocket/cassette","title":"CassetteOpts","content":"pub type CassetteOpts {\n  CassetteOpts(debug: Bool)\n}\n\nCassetteOpts(debug: Bool)\n\n\nSynonyms:\nsprocket/cassette.CassetteOpts\nsprocket/cassette CassetteOpts","url":"sprocket/cassette.html#CassetteOpts"},{"doc":"sprocket/cassette","title":"LiveService","content":"pub type LiveService {\n  LiveService(\n    id: Unique,\n    on_msg: fn(String, Unique, fn(String) -&gt; Result(Nil, Nil)) -&gt;\n      Result(Nil, Nil),\n    on_init: fn(Unique) -&gt; Result(Nil, Nil),\n    on_close: fn(Unique) -&gt; Result(Nil, Nil),\n  )\n}\n\nLiveService(\n  id: Unique,\n  on_msg: fn(String, Unique, fn(String) -&gt; Result(Nil, Nil)) -&gt;\n    Result(Nil, Nil),\n  on_init: fn(Unique) -&gt; Result(Nil, Nil),\n  on_close: fn(Unique) -&gt; Result(Nil, Nil),\n)\n\n\nSynonyms:\nsprocket/cassette.LiveService\nsprocket/cassette LiveService","url":"sprocket/cassette.html#LiveService"},{"doc":"sprocket/cassette","title":"Message","content":"pub type Message {\n  Shutdown\n  GetState(reply_with: Subject(State))\n  PushPreflight(preflight: Preflight)\n  CleanupPreflights\n  StartPreflightCleanupJob(cleanup_preflights: fn() -&gt; Nil)\n  PopPreflight(\n    reply_with: Subject(Result(Preflight, Nil)),\n    id: String,\n  )\n  PushSprocket(sprocket: Sprocket)\n  GetSprocket(\n    reply_with: Subject(Result(Sprocket, Nil)),\n    ws: Unique,\n  )\n  PopSprocket(\n    reply_with: Subject(Result(Sprocket, Nil)),\n    ws: Unique,\n  )\n}\n\nShutdown\n\n\nGetState(reply_with: Subject(State))\n\n\nPushPreflight(preflight: Preflight)\n\n\nCleanupPreflights\n\n\nStartPreflightCleanupJob(cleanup_preflights: fn() -&gt; Nil)\n\n\nPopPreflight(\n  reply_with: Subject(Result(Preflight, Nil)),\n  id: String,\n)\n\n\nPushSprocket(sprocket: Sprocket)\n\n\nGetSprocket(\n  reply_with: Subject(Result(Sprocket, Nil)),\n  ws: Unique,\n)\n\n\nPopSprocket(\n  reply_with: Subject(Result(Sprocket, Nil)),\n  ws: Unique,\n)\n\n\nSynonyms:\nsprocket/cassette.Message\nsprocket/cassette Message","url":"sprocket/cassette.html#Message"},{"doc":"sprocket/cassette","title":"Preflight","content":"pub type Preflight {\n  Preflight(\n    id: String,\n    view: Element,\n    csrf_token: String,\n    created_at: Int,\n  )\n}\n\nPreflight(\n  id: String,\n  view: Element,\n  csrf_token: String,\n  created_at: Int,\n)\n\n\nSynonyms:\nsprocket/cassette.Preflight\nsprocket/cassette Preflight","url":"sprocket/cassette.html#Preflight"},{"doc":"sprocket/cassette","title":"State","content":"pub type State {\n  State(\n    sprockets: List(Sprocket),\n    preflights: List(Preflight),\n    cancel_preflight_cleanup_job: fn() -&gt; Nil,\n    debug: Bool,\n  )\n}\n\nState(\n  sprockets: List(Sprocket),\n  preflights: List(Preflight),\n  cancel_preflight_cleanup_job: fn() -&gt; Nil,\n  debug: Bool,\n)\n\n\nSynonyms:\nsprocket/cassette.State\nsprocket/cassette State","url":"sprocket/cassette.html#State"},{"doc":"sprocket/cassette","title":"get_state","content":"pub fn get_state(ca: Subject(Message)) -&gt; State\n Get the current state of the cassette. Mostly intended for unit tests and debugging.\nSynonyms:\nsprocket/cassette.get_state\nsprocket/cassette get_state","url":"sprocket/cassette.html#get_state"},{"doc":"sprocket/cassette","title":"live_service","content":"pub fn live_service(ca: Subject(Message)) -&gt; LiveService\n Returns a live service specification for a sprocket websocket.\n \n This is a generic interface for handling websocket messages that can be\n used to implement a live service for a sprocket with a variety of different\n web servers.\n \n Refer to the example docs repository for an example of how to use this.\nSynonyms:\nsprocket/cassette.live_service\nsprocket/cassette live_service","url":"sprocket/cassette.html#live_service"},{"doc":"sprocket/cassette","title":"pop_preflight","content":"pub fn pop_preflight(ca: Subject(Message), id: String) -&gt; Result(\n  Preflight,\n  Nil,\n)\n Pops a preflight from the cassette.\nSynonyms:\nsprocket/cassette.pop_preflight\nsprocket/cassette pop_preflight","url":"sprocket/cassette.html#pop_preflight"},{"doc":"sprocket/cassette","title":"push_preflight","content":"pub fn push_preflight(ca: Subject(Message), preflight: Preflight) -&gt; Preflight\n Pushes a preflight to the cassette.\nSynonyms:\nsprocket/cassette.push_preflight\nsprocket/cassette push_preflight","url":"sprocket/cassette.html#push_preflight"},{"doc":"sprocket/cassette","title":"start","content":"pub fn start(opts: Option(CassetteOpts)) -&gt; Subject(Message)\n Start the cassette. This is intended to only be called once during web server\n initiliazation.\n \n The cassette is a long running process that manages the state of\n all sprockets and preflights.\nSynonyms:\nsprocket/cassette.start\nsprocket/cassette start","url":"sprocket/cassette.html#start"},{"doc":"sprocket/cassette","title":"stop","content":"pub fn stop(ca: Subject(Message)) -&gt; Nil\n Stop the cassette\nSynonyms:\nsprocket/cassette.stop\nsprocket/cassette stop","url":"sprocket/cassette.html#stop"},{"doc":"sprocket/cassette","title":"sprocket/cassette","content":"","url":"sprocket/cassette.html"},{"doc":"test_helpers","title":"Event","content":"pub type Event {\n  ClickEvent\n}\n\nClickEvent\n\n\nSynonyms:\ntest_helpers.Event\ntest_helpers Event","url":"test_helpers.html#Event"},{"doc":"test_helpers","title":"live","content":"pub fn live(view: Element) -&gt; Subject(Message)\n\nSynonyms:\ntest_helpers.live\ntest_helpers live","url":"test_helpers.html#live"},{"doc":"test_helpers","title":"render_event","content":"pub fn render_event(spkt: Subject(Message), event: Event, html_id: String) -&gt; Subject(\n  Message,\n)\n\nSynonyms:\ntest_helpers.render_event\ntest_helpers render_event","url":"test_helpers.html#render_event"},{"doc":"test_helpers","title":"render_html","content":"pub fn render_html(spkt: Subject(Message)) -&gt; #(\n  Subject(Message),\n  String,\n)\n\nSynonyms:\ntest_helpers.render_html\ntest_helpers render_html","url":"test_helpers.html#render_html"},{"doc":"test_helpers","title":"test_helpers","content":"","url":"test_helpers.html"},{"doc":"sprocket/component","title":"component","content":"pub fn component(c: fn(Context, a) -&gt; #(Context, List(Element)), props: a) -&gt; Element\n\nSynonyms:\nsprocket/component.component\nsprocket/component component","url":"sprocket/component.html#component"},{"doc":"sprocket/component","title":"render","content":"pub fn render(ctx: Context, elements: List(Element)) -&gt; #(\n  Context,\n  List(Element),\n)\n\nSynonyms:\nsprocket/component.render\nsprocket/component render","url":"sprocket/component.html#render"},{"doc":"sprocket/component","title":"sprocket/component","content":"","url":"sprocket/component.html"},{"doc":"sprocket/html/svg/elements","title":"a","content":"pub fn a(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;a&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/a)\nSynonyms:\nsprocket/html/svg/elements.a\nsprocket/html/svg/elements a","url":"sprocket/html/svg/elements.html#a"},{"doc":"sprocket/html/svg/elements","title":"animate","content":"pub fn animate(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;animate&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/animate)\nSynonyms:\nsprocket/html/svg/elements.animate\nsprocket/html/svg/elements animate","url":"sprocket/html/svg/elements.html#animate"},{"doc":"sprocket/html/svg/elements","title":"animate_motion","content":"pub fn animate_motion(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;animateMotion&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/animateMotion)\nSynonyms:\nsprocket/html/svg/elements.animate_motion\nsprocket/html/svg/elements animate_motion","url":"sprocket/html/svg/elements.html#animate_motion"},{"doc":"sprocket/html/svg/elements","title":"animate_transform","content":"pub fn animate_transform(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;animateTransform&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/animateTransform)\nSynonyms:\nsprocket/html/svg/elements.animate_transform\nsprocket/html/svg/elements animate_transform","url":"sprocket/html/svg/elements.html#animate_transform"},{"doc":"sprocket/html/svg/elements","title":"circle","content":"pub fn circle(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;circle&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/circle)\nSynonyms:\nsprocket/html/svg/elements.circle\nsprocket/html/svg/elements circle","url":"sprocket/html/svg/elements.html#circle"},{"doc":"sprocket/html/svg/elements","title":"clip_path","content":"pub fn clip_path(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;clipPath&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/clipPath)\nSynonyms:\nsprocket/html/svg/elements.clip_path\nsprocket/html/svg/elements clip_path","url":"sprocket/html/svg/elements.html#clip_path"},{"doc":"sprocket/html/svg/elements","title":"defs","content":"pub fn defs(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;defs&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/defs)\nSynonyms:\nsprocket/html/svg/elements.defs\nsprocket/html/svg/elements defs","url":"sprocket/html/svg/elements.html#defs"},{"doc":"sprocket/html/svg/elements","title":"desc","content":"pub fn desc(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;desc&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/desc)\nSynonyms:\nsprocket/html/svg/elements.desc\nsprocket/html/svg/elements desc","url":"sprocket/html/svg/elements.html#desc"},{"doc":"sprocket/html/svg/elements","title":"ellipse","content":"pub fn ellipse(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;ellipse&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/ellipse)\nSynonyms:\nsprocket/html/svg/elements.ellipse\nsprocket/html/svg/elements ellipse","url":"sprocket/html/svg/elements.html#ellipse"},{"doc":"sprocket/html/svg/elements","title":"fe_blend","content":"pub fn fe_blend(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;feBlend&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feBlend)\nSynonyms:\nsprocket/html/svg/elements.fe_blend\nsprocket/html/svg/elements fe_blend","url":"sprocket/html/svg/elements.html#fe_blend"},{"doc":"sprocket/html/svg/elements","title":"fe_color_matrix","content":"pub fn fe_color_matrix(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feColorMatrix&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feColorMatrix)\nSynonyms:\nsprocket/html/svg/elements.fe_color_matrix\nsprocket/html/svg/elements fe_color_matrix","url":"sprocket/html/svg/elements.html#fe_color_matrix"},{"doc":"sprocket/html/svg/elements","title":"fe_component_transfer","content":"pub fn fe_component_transfer(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feComponentTransfer&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feComponentTransfer)\nSynonyms:\nsprocket/html/svg/elements.fe_component_transfer\nsprocket/html/svg/elements fe_component_transfer","url":"sprocket/html/svg/elements.html#fe_component_transfer"},{"doc":"sprocket/html/svg/elements","title":"fe_composite","content":"pub fn fe_composite(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feComposite&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feComposite)\nSynonyms:\nsprocket/html/svg/elements.fe_composite\nsprocket/html/svg/elements fe_composite","url":"sprocket/html/svg/elements.html#fe_composite"},{"doc":"sprocket/html/svg/elements","title":"fe_convolve_matrix","content":"pub fn fe_convolve_matrix(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feConvolveMatrix&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feConvolveMatrix)\nSynonyms:\nsprocket/html/svg/elements.fe_convolve_matrix\nsprocket/html/svg/elements fe_convolve_matrix","url":"sprocket/html/svg/elements.html#fe_convolve_matrix"},{"doc":"sprocket/html/svg/elements","title":"fe_diffuse_lighting","content":"pub fn fe_diffuse_lighting(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feDiffuseLighting&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDiffuseLighting)\nSynonyms:\nsprocket/html/svg/elements.fe_diffuse_lighting\nsprocket/html/svg/elements fe_diffuse_lighting","url":"sprocket/html/svg/elements.html#fe_diffuse_lighting"},{"doc":"sprocket/html/svg/elements","title":"fe_displacement_map","content":"pub fn fe_displacement_map(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feDisplacementMap&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDisplacementMap)\nSynonyms:\nsprocket/html/svg/elements.fe_displacement_map\nsprocket/html/svg/elements fe_displacement_map","url":"sprocket/html/svg/elements.html#fe_displacement_map"},{"doc":"sprocket/html/svg/elements","title":"fe_distant_light","content":"pub fn fe_distant_light(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feDistantLight&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDistantLight)\nSynonyms:\nsprocket/html/svg/elements.fe_distant_light\nsprocket/html/svg/elements fe_distant_light","url":"sprocket/html/svg/elements.html#fe_distant_light"},{"doc":"sprocket/html/svg/elements","title":"fe_drop_shadow","content":"pub fn fe_drop_shadow(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feDropShadow&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDropShadow)\nSynonyms:\nsprocket/html/svg/elements.fe_drop_shadow\nsprocket/html/svg/elements fe_drop_shadow","url":"sprocket/html/svg/elements.html#fe_drop_shadow"},{"doc":"sprocket/html/svg/elements","title":"fe_flood","content":"pub fn fe_flood(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;feFlood&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFlood)\nSynonyms:\nsprocket/html/svg/elements.fe_flood\nsprocket/html/svg/elements fe_flood","url":"sprocket/html/svg/elements.html#fe_flood"},{"doc":"sprocket/html/svg/elements","title":"fe_func_a","content":"pub fn fe_func_a(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;feFuncA&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncA)\nSynonyms:\nsprocket/html/svg/elements.fe_func_a\nsprocket/html/svg/elements fe_func_a","url":"sprocket/html/svg/elements.html#fe_func_a"},{"doc":"sprocket/html/svg/elements","title":"fe_func_b","content":"pub fn fe_func_b(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;feFuncB&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncB)\nSynonyms:\nsprocket/html/svg/elements.fe_func_b\nsprocket/html/svg/elements fe_func_b","url":"sprocket/html/svg/elements.html#fe_func_b"},{"doc":"sprocket/html/svg/elements","title":"fe_func_g","content":"pub fn fe_func_g(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;feFuncG&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncG)\nSynonyms:\nsprocket/html/svg/elements.fe_func_g\nsprocket/html/svg/elements fe_func_g","url":"sprocket/html/svg/elements.html#fe_func_g"},{"doc":"sprocket/html/svg/elements","title":"fe_func_r","content":"pub fn fe_func_r(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;feFuncR&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncR)\nSynonyms:\nsprocket/html/svg/elements.fe_func_r\nsprocket/html/svg/elements fe_func_r","url":"sprocket/html/svg/elements.html#fe_func_r"},{"doc":"sprocket/html/svg/elements","title":"fe_gaussian_blur","content":"pub fn fe_gaussian_blur(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feGaussianBlur&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feGaussianBlur)\nSynonyms:\nsprocket/html/svg/elements.fe_gaussian_blur\nsprocket/html/svg/elements fe_gaussian_blur","url":"sprocket/html/svg/elements.html#fe_gaussian_blur"},{"doc":"sprocket/html/svg/elements","title":"fe_image","content":"pub fn fe_image(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;feImage&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feImage)\nSynonyms:\nsprocket/html/svg/elements.fe_image\nsprocket/html/svg/elements fe_image","url":"sprocket/html/svg/elements.html#fe_image"},{"doc":"sprocket/html/svg/elements","title":"fe_merge","content":"pub fn fe_merge(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;feMerge&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feMerge)\nSynonyms:\nsprocket/html/svg/elements.fe_merge\nsprocket/html/svg/elements fe_merge","url":"sprocket/html/svg/elements.html#fe_merge"},{"doc":"sprocket/html/svg/elements","title":"fe_merge_node","content":"pub fn fe_merge_node(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feMergeNode&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feMergeNode)\nSynonyms:\nsprocket/html/svg/elements.fe_merge_node\nsprocket/html/svg/elements fe_merge_node","url":"sprocket/html/svg/elements.html#fe_merge_node"},{"doc":"sprocket/html/svg/elements","title":"fe_morphology","content":"pub fn fe_morphology(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feMorphology&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feMorphology)\nSynonyms:\nsprocket/html/svg/elements.fe_morphology\nsprocket/html/svg/elements fe_morphology","url":"sprocket/html/svg/elements.html#fe_morphology"},{"doc":"sprocket/html/svg/elements","title":"fe_offset","content":"pub fn fe_offset(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;feOffset&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feOffset)\nSynonyms:\nsprocket/html/svg/elements.fe_offset\nsprocket/html/svg/elements fe_offset","url":"sprocket/html/svg/elements.html#fe_offset"},{"doc":"sprocket/html/svg/elements","title":"fe_point_light","content":"pub fn fe_point_light(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;fePointLight&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/fePointLight)\nSynonyms:\nsprocket/html/svg/elements.fe_point_light\nsprocket/html/svg/elements fe_point_light","url":"sprocket/html/svg/elements.html#fe_point_light"},{"doc":"sprocket/html/svg/elements","title":"fe_specular_lighting","content":"pub fn fe_specular_lighting(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feSpecularLighting&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feSpecularLighting)\nSynonyms:\nsprocket/html/svg/elements.fe_specular_lighting\nsprocket/html/svg/elements fe_specular_lighting","url":"sprocket/html/svg/elements.html#fe_specular_lighting"},{"doc":"sprocket/html/svg/elements","title":"fe_spot_light","content":"pub fn fe_spot_light(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feSpotLight&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feSpotLight)\nSynonyms:\nsprocket/html/svg/elements.fe_spot_light\nsprocket/html/svg/elements fe_spot_light","url":"sprocket/html/svg/elements.html#fe_spot_light"},{"doc":"sprocket/html/svg/elements","title":"fe_tile","content":"pub fn fe_tile(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;feTile&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feTile)\nSynonyms:\nsprocket/html/svg/elements.fe_tile\nsprocket/html/svg/elements fe_tile","url":"sprocket/html/svg/elements.html#fe_tile"},{"doc":"sprocket/html/svg/elements","title":"fe_turbulence","content":"pub fn fe_turbulence(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;feTurbulence&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feTurbulence)\nSynonyms:\nsprocket/html/svg/elements.fe_turbulence\nsprocket/html/svg/elements fe_turbulence","url":"sprocket/html/svg/elements.html#fe_turbulence"},{"doc":"sprocket/html/svg/elements","title":"filter","content":"pub fn filter(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;filter&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/filter)\nSynonyms:\nsprocket/html/svg/elements.filter\nsprocket/html/svg/elements filter","url":"sprocket/html/svg/elements.html#filter"},{"doc":"sprocket/html/svg/elements","title":"foreign_object","content":"pub fn foreign_object(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;foreignObject&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/foreignObject)\nSynonyms:\nsprocket/html/svg/elements.foreign_object\nsprocket/html/svg/elements foreign_object","url":"sprocket/html/svg/elements.html#foreign_object"},{"doc":"sprocket/html/svg/elements","title":"g","content":"pub fn g(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;g&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/g)\nSynonyms:\nsprocket/html/svg/elements.g\nsprocket/html/svg/elements g","url":"sprocket/html/svg/elements.html#g"},{"doc":"sprocket/html/svg/elements","title":"hatch","content":"pub fn hatch(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;hatch&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/hatch)\nSynonyms:\nsprocket/html/svg/elements.hatch\nsprocket/html/svg/elements hatch","url":"sprocket/html/svg/elements.html#hatch"},{"doc":"sprocket/html/svg/elements","title":"hatchpath","content":"pub fn hatchpath(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;hatchpath&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/hatchpath)\nSynonyms:\nsprocket/html/svg/elements.hatchpath\nsprocket/html/svg/elements hatchpath","url":"sprocket/html/svg/elements.html#hatchpath"},{"doc":"sprocket/html/svg/elements","title":"image","content":"pub fn image(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;image&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/image)\nSynonyms:\nsprocket/html/svg/elements.image\nsprocket/html/svg/elements image","url":"sprocket/html/svg/elements.html#image"},{"doc":"sprocket/html/svg/elements","title":"line","content":"pub fn line(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;line&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/line)\nSynonyms:\nsprocket/html/svg/elements.line\nsprocket/html/svg/elements line","url":"sprocket/html/svg/elements.html#line"},{"doc":"sprocket/html/svg/elements","title":"linear_gradient","content":"pub fn linear_gradient(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;linearGradient&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/linearGradient)\nSynonyms:\nsprocket/html/svg/elements.linear_gradient\nsprocket/html/svg/elements linear_gradient","url":"sprocket/html/svg/elements.html#linear_gradient"},{"doc":"sprocket/html/svg/elements","title":"marker","content":"pub fn marker(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;marker&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/marker)\nSynonyms:\nsprocket/html/svg/elements.marker\nsprocket/html/svg/elements marker","url":"sprocket/html/svg/elements.html#marker"},{"doc":"sprocket/html/svg/elements","title":"mask","content":"pub fn mask(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;mask&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/mask)\nSynonyms:\nsprocket/html/svg/elements.mask\nsprocket/html/svg/elements mask","url":"sprocket/html/svg/elements.html#mask"},{"doc":"sprocket/html/svg/elements","title":"metadata","content":"pub fn metadata(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;metadata&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/metadata)\nSynonyms:\nsprocket/html/svg/elements.metadata\nsprocket/html/svg/elements metadata","url":"sprocket/html/svg/elements.html#metadata"},{"doc":"sprocket/html/svg/elements","title":"mpath","content":"pub fn mpath(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;mpath&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/mpath)\nSynonyms:\nsprocket/html/svg/elements.mpath\nsprocket/html/svg/elements mpath","url":"sprocket/html/svg/elements.html#mpath"},{"doc":"sprocket/html/svg/elements","title":"path","content":"pub fn path(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;path&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/path)\nSynonyms:\nsprocket/html/svg/elements.path\nsprocket/html/svg/elements path","url":"sprocket/html/svg/elements.html#path"},{"doc":"sprocket/html/svg/elements","title":"pattern","content":"pub fn pattern(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;pattern&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/pattern)\nSynonyms:\nsprocket/html/svg/elements.pattern\nsprocket/html/svg/elements pattern","url":"sprocket/html/svg/elements.html#pattern"},{"doc":"sprocket/html/svg/elements","title":"polygon","content":"pub fn polygon(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;polygon&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/polygon)\nSynonyms:\nsprocket/html/svg/elements.polygon\nsprocket/html/svg/elements polygon","url":"sprocket/html/svg/elements.html#polygon"},{"doc":"sprocket/html/svg/elements","title":"polyline","content":"pub fn polyline(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;polyline&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/polyline)\nSynonyms:\nsprocket/html/svg/elements.polyline\nsprocket/html/svg/elements polyline","url":"sprocket/html/svg/elements.html#polyline"},{"doc":"sprocket/html/svg/elements","title":"radial_gradient","content":"pub fn radial_gradient(attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n The [SVG `&lt;radialGradient&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/radialGradient)\nSynonyms:\nsprocket/html/svg/elements.radial_gradient\nsprocket/html/svg/elements radial_gradient","url":"sprocket/html/svg/elements.html#radial_gradient"},{"doc":"sprocket/html/svg/elements","title":"rect","content":"pub fn rect(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;rect&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/rect)\nSynonyms:\nsprocket/html/svg/elements.rect\nsprocket/html/svg/elements rect","url":"sprocket/html/svg/elements.html#rect"},{"doc":"sprocket/html/svg/elements","title":"script","content":"pub fn script(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;script&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/script)\nSynonyms:\nsprocket/html/svg/elements.script\nsprocket/html/svg/elements script","url":"sprocket/html/svg/elements.html#script"},{"doc":"sprocket/html/svg/elements","title":"set","content":"pub fn set(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;set&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/set)\nSynonyms:\nsprocket/html/svg/elements.set\nsprocket/html/svg/elements set","url":"sprocket/html/svg/elements.html#set"},{"doc":"sprocket/html/svg/elements","title":"stop","content":"pub fn stop(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;stop&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/stop)\nSynonyms:\nsprocket/html/svg/elements.stop\nsprocket/html/svg/elements stop","url":"sprocket/html/svg/elements.html#stop"},{"doc":"sprocket/html/svg/elements","title":"style","content":"pub fn style(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;style&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/style)\nSynonyms:\nsprocket/html/svg/elements.style\nsprocket/html/svg/elements style","url":"sprocket/html/svg/elements.html#style"},{"doc":"sprocket/html/svg/elements","title":"svg","content":"pub fn svg(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;svg&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/svg)\nSynonyms:\nsprocket/html/svg/elements.svg\nsprocket/html/svg/elements svg","url":"sprocket/html/svg/elements.html#svg"},{"doc":"sprocket/html/svg/elements","title":"switch","content":"pub fn switch(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;switch&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/switch)\nSynonyms:\nsprocket/html/svg/elements.switch\nsprocket/html/svg/elements switch","url":"sprocket/html/svg/elements.html#switch"},{"doc":"sprocket/html/svg/elements","title":"symbol","content":"pub fn symbol(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;symbol&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/symbol)\nSynonyms:\nsprocket/html/svg/elements.symbol\nsprocket/html/svg/elements symbol","url":"sprocket/html/svg/elements.html#symbol"},{"doc":"sprocket/html/svg/elements","title":"text","content":"pub fn text(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;text&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/text)\nSynonyms:\nsprocket/html/svg/elements.text\nsprocket/html/svg/elements text","url":"sprocket/html/svg/elements.html#text"},{"doc":"sprocket/html/svg/elements","title":"text_path","content":"pub fn text_path(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;textPath&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/textPath)\nSynonyms:\nsprocket/html/svg/elements.text_path\nsprocket/html/svg/elements text_path","url":"sprocket/html/svg/elements.html#text_path"},{"doc":"sprocket/html/svg/elements","title":"title","content":"pub fn title(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;title&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/title)\nSynonyms:\nsprocket/html/svg/elements.title\nsprocket/html/svg/elements title","url":"sprocket/html/svg/elements.html#title"},{"doc":"sprocket/html/svg/elements","title":"tspan","content":"pub fn tspan(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;tspan&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/tspan)\nSynonyms:\nsprocket/html/svg/elements.tspan\nsprocket/html/svg/elements tspan","url":"sprocket/html/svg/elements.html#tspan"},{"doc":"sprocket/html/svg/elements","title":"use_","content":"pub fn use_(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;use&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/use)\nSynonyms:\nsprocket/html/svg/elements.use_\nsprocket/html/svg/elements use_","url":"sprocket/html/svg/elements.html#use_"},{"doc":"sprocket/html/svg/elements","title":"view","content":"pub fn view(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [SVG `&lt;view&gt;` element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/view)\nSynonyms:\nsprocket/html/svg/elements.view\nsprocket/html/svg/elements view","url":"sprocket/html/svg/elements.html#view"},{"doc":"sprocket/html/svg/elements","title":"sprocket/html/svg/elements","content":"","url":"sprocket/html/svg/elements.html"},{"doc":"sprocket/hooks/reducer","title":"Updater","content":"pub type Updater(msg) =\n  fn(msg) -&gt; Nil\n\n\nSynonyms:\nsprocket/hooks/reducer.Updater\nsprocket/hooks/reducer Updater","url":"sprocket/hooks/reducer.html#Updater"},{"doc":"sprocket/hooks/reducer","title":"reducer","content":"pub fn reducer(ctx: Context, initial: a, reducer: fn(a, b) -&gt; a, cb: fn(\n    Context,\n    a,\n    fn(b) -&gt; Nil,\n  ) -&gt; #(Context, List(Element))) -&gt; #(Context, List(Element))\n\nSynonyms:\nsprocket/hooks/reducer.reducer\nsprocket/hooks/reducer reducer","url":"sprocket/hooks/reducer.html#reducer"},{"doc":"sprocket/hooks/reducer","title":"sprocket/hooks/reducer","content":"","url":"sprocket/hooks/reducer.html"},{"doc":"sprocket/hooks/state","title":"state","content":"pub fn state(ctx: Context, initial: a, cb: fn(\n    Context,\n    a,\n    fn(a) -&gt; Nil,\n  ) -&gt; #(Context, List(Element))) -&gt; #(Context, List(Element))\n\nSynonyms:\nsprocket/hooks/state.state\nsprocket/hooks/state state","url":"sprocket/hooks/state.html#state"},{"doc":"sprocket/hooks/state","title":"sprocket/hooks/state","content":"","url":"sprocket/hooks/state.html"},{"doc":"sprocket/hooks/effect","title":"effect","content":"pub fn effect(ctx: Context, effect_fn: fn() -&gt;\n    Option(fn() -&gt; Nil), trigger: HookTrigger, cb: fn(Context) -&gt;\n    #(Context, List(Element))) -&gt; #(Context, List(Element))\n\nSynonyms:\nsprocket/hooks/effect.effect\nsprocket/hooks/effect effect","url":"sprocket/hooks/effect.html#effect"},{"doc":"sprocket/hooks/effect","title":"sprocket/hooks/effect","content":"","url":"sprocket/hooks/effect.html"},{"doc":"sprocket/html/svg/attributes","title":"accent_height","content":"pub fn accent_height(value: String) -&gt; Attribute\n The [SVG `accent-height` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/accent-height)\nSynonyms:\nsprocket/html/svg/attributes.accent_height\nsprocket/html/svg/attributes accent_height","url":"sprocket/html/svg/attributes.html#accent_height"},{"doc":"sprocket/html/svg/attributes","title":"accumulate","content":"pub fn accumulate(value: String) -&gt; Attribute\n The [SVG `accumulate` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/accumulate)\nSynonyms:\nsprocket/html/svg/attributes.accumulate\nsprocket/html/svg/attributes accumulate","url":"sprocket/html/svg/attributes.html#accumulate"},{"doc":"sprocket/html/svg/attributes","title":"additive","content":"pub fn additive(value: String) -&gt; Attribute\n The [SVG `additive` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/additive)\nSynonyms:\nsprocket/html/svg/attributes.additive\nsprocket/html/svg/attributes additive","url":"sprocket/html/svg/attributes.html#additive"},{"doc":"sprocket/html/svg/attributes","title":"alignment_baseline","content":"pub fn alignment_baseline(value: String) -&gt; Attribute\n The [SVG `alignment-baseline` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/alignment-baseline)\nSynonyms:\nsprocket/html/svg/attributes.alignment_baseline\nsprocket/html/svg/attributes alignment_baseline","url":"sprocket/html/svg/attributes.html#alignment_baseline"},{"doc":"sprocket/html/svg/attributes","title":"alphabetic","content":"pub fn alphabetic(value: String) -&gt; Attribute\n The [SVG `alphabetic` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/alphabetic)\nSynonyms:\nsprocket/html/svg/attributes.alphabetic\nsprocket/html/svg/attributes alphabetic","url":"sprocket/html/svg/attributes.html#alphabetic"},{"doc":"sprocket/html/svg/attributes","title":"amplitude","content":"pub fn amplitude(value: String) -&gt; Attribute\n The [SVG `amplitude` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/amplitude)\nSynonyms:\nsprocket/html/svg/attributes.amplitude\nsprocket/html/svg/attributes amplitude","url":"sprocket/html/svg/attributes.html#amplitude"},{"doc":"sprocket/html/svg/attributes","title":"arabic_form","content":"pub fn arabic_form(value: String) -&gt; Attribute\n The [SVG `arabic-form` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/arabic-form)\nSynonyms:\nsprocket/html/svg/attributes.arabic_form\nsprocket/html/svg/attributes arabic_form","url":"sprocket/html/svg/attributes.html#arabic_form"},{"doc":"sprocket/html/svg/attributes","title":"ascent","content":"pub fn ascent(value: String) -&gt; Attribute\n The [SVG `ascent` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/ascent)\nSynonyms:\nsprocket/html/svg/attributes.ascent\nsprocket/html/svg/attributes ascent","url":"sprocket/html/svg/attributes.html#ascent"},{"doc":"sprocket/html/svg/attributes","title":"attribute_name","content":"pub fn attribute_name(value: String) -&gt; Attribute\n The [SVG `attributeName` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/attributeName)\nSynonyms:\nsprocket/html/svg/attributes.attribute_name\nsprocket/html/svg/attributes attribute_name","url":"sprocket/html/svg/attributes.html#attribute_name"},{"doc":"sprocket/html/svg/attributes","title":"attribute_type","content":"pub fn attribute_type(value: String) -&gt; Attribute\n The [SVG `attributeType` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/attributeType)\nSynonyms:\nsprocket/html/svg/attributes.attribute_type\nsprocket/html/svg/attributes attribute_type","url":"sprocket/html/svg/attributes.html#attribute_type"},{"doc":"sprocket/html/svg/attributes","title":"azimuth","content":"pub fn azimuth(value: String) -&gt; Attribute\n The [SVG `azimuth` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/azimuth)\nSynonyms:\nsprocket/html/svg/attributes.azimuth\nsprocket/html/svg/attributes azimuth","url":"sprocket/html/svg/attributes.html#azimuth"},{"doc":"sprocket/html/svg/attributes","title":"base_frequency","content":"pub fn base_frequency(value: String) -&gt; Attribute\n The [SVG `baseFrequency` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/baseFrequency)\nSynonyms:\nsprocket/html/svg/attributes.base_frequency\nsprocket/html/svg/attributes base_frequency","url":"sprocket/html/svg/attributes.html#base_frequency"},{"doc":"sprocket/html/svg/attributes","title":"base_profile","content":"pub fn base_profile(value: String) -&gt; Attribute\n The [SVG `baseProfile` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/baseProfile)\nSynonyms:\nsprocket/html/svg/attributes.base_profile\nsprocket/html/svg/attributes base_profile","url":"sprocket/html/svg/attributes.html#base_profile"},{"doc":"sprocket/html/svg/attributes","title":"baseline_shift","content":"pub fn baseline_shift(value: String) -&gt; Attribute\n The [SVG `baseline-shift` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/baseline-shift)\nSynonyms:\nsprocket/html/svg/attributes.baseline_shift\nsprocket/html/svg/attributes baseline_shift","url":"sprocket/html/svg/attributes.html#baseline_shift"},{"doc":"sprocket/html/svg/attributes","title":"bbox","content":"pub fn bbox(value: String) -&gt; Attribute\n The [SVG `bbox` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/bbox)\nSynonyms:\nsprocket/html/svg/attributes.bbox\nsprocket/html/svg/attributes bbox","url":"sprocket/html/svg/attributes.html#bbox"},{"doc":"sprocket/html/svg/attributes","title":"begin","content":"pub fn begin(value: String) -&gt; Attribute\n The [SVG `begin` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/begin)\nSynonyms:\nsprocket/html/svg/attributes.begin\nsprocket/html/svg/attributes begin","url":"sprocket/html/svg/attributes.html#begin"},{"doc":"sprocket/html/svg/attributes","title":"bias","content":"pub fn bias(value: String) -&gt; Attribute\n The [SVG `bias` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/bias)\nSynonyms:\nsprocket/html/svg/attributes.bias\nsprocket/html/svg/attributes bias","url":"sprocket/html/svg/attributes.html#bias"},{"doc":"sprocket/html/svg/attributes","title":"by","content":"pub fn by(value: String) -&gt; Attribute\n The [SVG `by` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/by)\nSynonyms:\nsprocket/html/svg/attributes.by\nsprocket/html/svg/attributes by","url":"sprocket/html/svg/attributes.html#by"},{"doc":"sprocket/html/svg/attributes","title":"calc_mode","content":"pub fn calc_mode(value: String) -&gt; Attribute\n The [SVG `calcMode` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/calcMode)\nSynonyms:\nsprocket/html/svg/attributes.calc_mode\nsprocket/html/svg/attributes calc_mode","url":"sprocket/html/svg/attributes.html#calc_mode"},{"doc":"sprocket/html/svg/attributes","title":"cap_height","content":"pub fn cap_height(value: String) -&gt; Attribute\n The [SVG `cap-height` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/cap-height)\nSynonyms:\nsprocket/html/svg/attributes.cap_height\nsprocket/html/svg/attributes cap_height","url":"sprocket/html/svg/attributes.html#cap_height"},{"doc":"sprocket/html/svg/attributes","title":"class","content":"pub fn class(value: String) -&gt; Attribute\n The [SVG `class` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/class)\nSynonyms:\nsprocket/html/svg/attributes.class\nsprocket/html/svg/attributes class","url":"sprocket/html/svg/attributes.html#class"},{"doc":"sprocket/html/svg/attributes","title":"clip","content":"pub fn clip(value: String) -&gt; Attribute\n The [SVG `clip` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/clip)\nSynonyms:\nsprocket/html/svg/attributes.clip\nsprocket/html/svg/attributes clip","url":"sprocket/html/svg/attributes.html#clip"},{"doc":"sprocket/html/svg/attributes","title":"clip_path","content":"pub fn clip_path(value: String) -&gt; Attribute\n The [SVG `clip-path` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/clip-path)\nSynonyms:\nsprocket/html/svg/attributes.clip_path\nsprocket/html/svg/attributes clip_path","url":"sprocket/html/svg/attributes.html#clip_path"},{"doc":"sprocket/html/svg/attributes","title":"clip_path_units","content":"pub fn clip_path_units(value: String) -&gt; Attribute\n The [SVG `clipPathUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/clipPathUnits)\nSynonyms:\nsprocket/html/svg/attributes.clip_path_units\nsprocket/html/svg/attributes clip_path_units","url":"sprocket/html/svg/attributes.html#clip_path_units"},{"doc":"sprocket/html/svg/attributes","title":"clip_rule","content":"pub fn clip_rule(value: String) -&gt; Attribute\n The [SVG `clip-rule` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/clip-rule)\nSynonyms:\nsprocket/html/svg/attributes.clip_rule\nsprocket/html/svg/attributes clip_rule","url":"sprocket/html/svg/attributes.html#clip_rule"},{"doc":"sprocket/html/svg/attributes","title":"color","content":"pub fn color(value: String) -&gt; Attribute\n The [SVG `color` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/color)\nSynonyms:\nsprocket/html/svg/attributes.color\nsprocket/html/svg/attributes color","url":"sprocket/html/svg/attributes.html#color"},{"doc":"sprocket/html/svg/attributes","title":"color_interpolation","content":"pub fn color_interpolation(value: String) -&gt; Attribute\n The [SVG `color-interpolation` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/color-interpolation)\nSynonyms:\nsprocket/html/svg/attributes.color_interpolation\nsprocket/html/svg/attributes color_interpolation","url":"sprocket/html/svg/attributes.html#color_interpolation"},{"doc":"sprocket/html/svg/attributes","title":"color_interpolation_filters","content":"pub fn color_interpolation_filters(value: String) -&gt; Attribute\n The [SVG `color-interpolation-filters` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/color-interpolation-filters)\nSynonyms:\nsprocket/html/svg/attributes.color_interpolation_filters\nsprocket/html/svg/attributes color_interpolation_filters","url":"sprocket/html/svg/attributes.html#color_interpolation_filters"},{"doc":"sprocket/html/svg/attributes","title":"color_profile","content":"pub fn color_profile(value: String) -&gt; Attribute\n The [SVG `color-profile` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/color-profile)\nSynonyms:\nsprocket/html/svg/attributes.color_profile\nsprocket/html/svg/attributes color_profile","url":"sprocket/html/svg/attributes.html#color_profile"},{"doc":"sprocket/html/svg/attributes","title":"color_rendering","content":"pub fn color_rendering(value: String) -&gt; Attribute\n The [SVG `color-rendering` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/color-rendering)\nSynonyms:\nsprocket/html/svg/attributes.color_rendering\nsprocket/html/svg/attributes color_rendering","url":"sprocket/html/svg/attributes.html#color_rendering"},{"doc":"sprocket/html/svg/attributes","title":"content_script_type","content":"pub fn content_script_type(value: String) -&gt; Attribute\n The [SVG `contentScriptType` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/contentScriptType)\nSynonyms:\nsprocket/html/svg/attributes.content_script_type\nsprocket/html/svg/attributes content_script_type","url":"sprocket/html/svg/attributes.html#content_script_type"},{"doc":"sprocket/html/svg/attributes","title":"content_style_type","content":"pub fn content_style_type(value: String) -&gt; Attribute\n The [SVG `contentStyleType` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/contentStyleType)\nSynonyms:\nsprocket/html/svg/attributes.content_style_type\nsprocket/html/svg/attributes content_style_type","url":"sprocket/html/svg/attributes.html#content_style_type"},{"doc":"sprocket/html/svg/attributes","title":"crossorigin","content":"pub fn crossorigin(value: String) -&gt; Attribute\n The [SVG `crossorigin` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/crossorigin)\nSynonyms:\nsprocket/html/svg/attributes.crossorigin\nsprocket/html/svg/attributes crossorigin","url":"sprocket/html/svg/attributes.html#crossorigin"},{"doc":"sprocket/html/svg/attributes","title":"cursor","content":"pub fn cursor(value: String) -&gt; Attribute\n The [SVG `cursor` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/cursor)\nSynonyms:\nsprocket/html/svg/attributes.cursor\nsprocket/html/svg/attributes cursor","url":"sprocket/html/svg/attributes.html#cursor"},{"doc":"sprocket/html/svg/attributes","title":"cx","content":"pub fn cx(value: String) -&gt; Attribute\n The [SVG `cx` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/cx)\nSynonyms:\nsprocket/html/svg/attributes.cx\nsprocket/html/svg/attributes cx","url":"sprocket/html/svg/attributes.html#cx"},{"doc":"sprocket/html/svg/attributes","title":"cy","content":"pub fn cy(value: String) -&gt; Attribute\n The [SVG `cy` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/cy)\nSynonyms:\nsprocket/html/svg/attributes.cy\nsprocket/html/svg/attributes cy","url":"sprocket/html/svg/attributes.html#cy"},{"doc":"sprocket/html/svg/attributes","title":"d","content":"pub fn d(value: String) -&gt; Attribute\n The [SVG `d` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/d)\nSynonyms:\nsprocket/html/svg/attributes.d\nsprocket/html/svg/attributes d","url":"sprocket/html/svg/attributes.html#d"},{"doc":"sprocket/html/svg/attributes","title":"decelerate","content":"pub fn decelerate(value: String) -&gt; Attribute\n The [SVG `decelerate` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/decelerate)\nSynonyms:\nsprocket/html/svg/attributes.decelerate\nsprocket/html/svg/attributes decelerate","url":"sprocket/html/svg/attributes.html#decelerate"},{"doc":"sprocket/html/svg/attributes","title":"descent","content":"pub fn descent(value: String) -&gt; Attribute\n The [SVG `descent` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/descent)\nSynonyms:\nsprocket/html/svg/attributes.descent\nsprocket/html/svg/attributes descent","url":"sprocket/html/svg/attributes.html#descent"},{"doc":"sprocket/html/svg/attributes","title":"diffuse_constant","content":"pub fn diffuse_constant(value: String) -&gt; Attribute\n The [SVG `diffuseConstant` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/diffuseConstant)\nSynonyms:\nsprocket/html/svg/attributes.diffuse_constant\nsprocket/html/svg/attributes diffuse_constant","url":"sprocket/html/svg/attributes.html#diffuse_constant"},{"doc":"sprocket/html/svg/attributes","title":"direction","content":"pub fn direction(value: String) -&gt; Attribute\n The [SVG `direction` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/direction)\nSynonyms:\nsprocket/html/svg/attributes.direction\nsprocket/html/svg/attributes direction","url":"sprocket/html/svg/attributes.html#direction"},{"doc":"sprocket/html/svg/attributes","title":"display","content":"pub fn display(value: String) -&gt; Attribute\n The [SVG `display` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/display)\nSynonyms:\nsprocket/html/svg/attributes.display\nsprocket/html/svg/attributes display","url":"sprocket/html/svg/attributes.html#display"},{"doc":"sprocket/html/svg/attributes","title":"divisor","content":"pub fn divisor(value: String) -&gt; Attribute\n The [SVG `divisor` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/divisor)\nSynonyms:\nsprocket/html/svg/attributes.divisor\nsprocket/html/svg/attributes divisor","url":"sprocket/html/svg/attributes.html#divisor"},{"doc":"sprocket/html/svg/attributes","title":"dominant_baseline","content":"pub fn dominant_baseline(value: String) -&gt; Attribute\n The [SVG `dominant-baseline` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/dominant-baseline)\nSynonyms:\nsprocket/html/svg/attributes.dominant_baseline\nsprocket/html/svg/attributes dominant_baseline","url":"sprocket/html/svg/attributes.html#dominant_baseline"},{"doc":"sprocket/html/svg/attributes","title":"dur","content":"pub fn dur(value: String) -&gt; Attribute\n The [SVG `dur` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/dur)\nSynonyms:\nsprocket/html/svg/attributes.dur\nsprocket/html/svg/attributes dur","url":"sprocket/html/svg/attributes.html#dur"},{"doc":"sprocket/html/svg/attributes","title":"dx","content":"pub fn dx(value: String) -&gt; Attribute\n The [SVG `dx` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/dx)\nSynonyms:\nsprocket/html/svg/attributes.dx\nsprocket/html/svg/attributes dx","url":"sprocket/html/svg/attributes.html#dx"},{"doc":"sprocket/html/svg/attributes","title":"dy","content":"pub fn dy(value: String) -&gt; Attribute\n The [SVG `dy` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/dy)\nSynonyms:\nsprocket/html/svg/attributes.dy\nsprocket/html/svg/attributes dy","url":"sprocket/html/svg/attributes.html#dy"},{"doc":"sprocket/html/svg/attributes","title":"edge_mode","content":"pub fn edge_mode(value: String) -&gt; Attribute\n The [SVG `edgeMode` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/edgeMode)\nSynonyms:\nsprocket/html/svg/attributes.edge_mode\nsprocket/html/svg/attributes edge_mode","url":"sprocket/html/svg/attributes.html#edge_mode"},{"doc":"sprocket/html/svg/attributes","title":"elevation","content":"pub fn elevation(value: String) -&gt; Attribute\n The [SVG `elevation` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/elevation)\nSynonyms:\nsprocket/html/svg/attributes.elevation\nsprocket/html/svg/attributes elevation","url":"sprocket/html/svg/attributes.html#elevation"},{"doc":"sprocket/html/svg/attributes","title":"enable_background","content":"pub fn enable_background(value: String) -&gt; Attribute\n The [SVG `enable-background` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/enable-background)\nSynonyms:\nsprocket/html/svg/attributes.enable_background\nsprocket/html/svg/attributes enable_background","url":"sprocket/html/svg/attributes.html#enable_background"},{"doc":"sprocket/html/svg/attributes","title":"end","content":"pub fn end(value: String) -&gt; Attribute\n The [SVG `end` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/end)\nSynonyms:\nsprocket/html/svg/attributes.end\nsprocket/html/svg/attributes end","url":"sprocket/html/svg/attributes.html#end"},{"doc":"sprocket/html/svg/attributes","title":"exponent","content":"pub fn exponent(value: String) -&gt; Attribute\n The [SVG `exponent` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/exponent)\nSynonyms:\nsprocket/html/svg/attributes.exponent\nsprocket/html/svg/attributes exponent","url":"sprocket/html/svg/attributes.html#exponent"},{"doc":"sprocket/html/svg/attributes","title":"fill","content":"pub fn fill(value: String) -&gt; Attribute\n The [SVG `fill` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/fill)\nSynonyms:\nsprocket/html/svg/attributes.fill\nsprocket/html/svg/attributes fill","url":"sprocket/html/svg/attributes.html#fill"},{"doc":"sprocket/html/svg/attributes","title":"fill_opacity","content":"pub fn fill_opacity(value: String) -&gt; Attribute\n The [SVG `fill-opacity` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/fill-opacity)\nSynonyms:\nsprocket/html/svg/attributes.fill_opacity\nsprocket/html/svg/attributes fill_opacity","url":"sprocket/html/svg/attributes.html#fill_opacity"},{"doc":"sprocket/html/svg/attributes","title":"fill_rule","content":"pub fn fill_rule(value: String) -&gt; Attribute\n The [SVG `fill-rule` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/fill-rule)\nSynonyms:\nsprocket/html/svg/attributes.fill_rule\nsprocket/html/svg/attributes fill_rule","url":"sprocket/html/svg/attributes.html#fill_rule"},{"doc":"sprocket/html/svg/attributes","title":"filter","content":"pub fn filter(value: String) -&gt; Attribute\n The [SVG `filter` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/filter)\nSynonyms:\nsprocket/html/svg/attributes.filter\nsprocket/html/svg/attributes filter","url":"sprocket/html/svg/attributes.html#filter"},{"doc":"sprocket/html/svg/attributes","title":"filter_res","content":"pub fn filter_res(value: String) -&gt; Attribute\n The [SVG `filterRes` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/filterRes)\nSynonyms:\nsprocket/html/svg/attributes.filter_res\nsprocket/html/svg/attributes filter_res","url":"sprocket/html/svg/attributes.html#filter_res"},{"doc":"sprocket/html/svg/attributes","title":"filter_units","content":"pub fn filter_units(value: String) -&gt; Attribute\n The [SVG `filterUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/filterUnits)\nSynonyms:\nsprocket/html/svg/attributes.filter_units\nsprocket/html/svg/attributes filter_units","url":"sprocket/html/svg/attributes.html#filter_units"},{"doc":"sprocket/html/svg/attributes","title":"flood_color","content":"pub fn flood_color(value: String) -&gt; Attribute\n The [SVG `flood-color` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/flood-color)\nSynonyms:\nsprocket/html/svg/attributes.flood_color\nsprocket/html/svg/attributes flood_color","url":"sprocket/html/svg/attributes.html#flood_color"},{"doc":"sprocket/html/svg/attributes","title":"flood_opacity","content":"pub fn flood_opacity(value: String) -&gt; Attribute\n The [SVG `flood-opacity` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/flood-opacity)\nSynonyms:\nsprocket/html/svg/attributes.flood_opacity\nsprocket/html/svg/attributes flood_opacity","url":"sprocket/html/svg/attributes.html#flood_opacity"},{"doc":"sprocket/html/svg/attributes","title":"font_family","content":"pub fn font_family(value: String) -&gt; Attribute\n The [SVG `font-family` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-family)\nSynonyms:\nsprocket/html/svg/attributes.font_family\nsprocket/html/svg/attributes font_family","url":"sprocket/html/svg/attributes.html#font_family"},{"doc":"sprocket/html/svg/attributes","title":"font_size","content":"pub fn font_size(value: String) -&gt; Attribute\n The [SVG `font-size` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-size)\nSynonyms:\nsprocket/html/svg/attributes.font_size\nsprocket/html/svg/attributes font_size","url":"sprocket/html/svg/attributes.html#font_size"},{"doc":"sprocket/html/svg/attributes","title":"font_size_adjust","content":"pub fn font_size_adjust(value: String) -&gt; Attribute\n The [SVG `font-size-adjust` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-size-adjust)\nSynonyms:\nsprocket/html/svg/attributes.font_size_adjust\nsprocket/html/svg/attributes font_size_adjust","url":"sprocket/html/svg/attributes.html#font_size_adjust"},{"doc":"sprocket/html/svg/attributes","title":"font_stretch","content":"pub fn font_stretch(value: String) -&gt; Attribute\n The [SVG `font-stretch` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-stretch)\nSynonyms:\nsprocket/html/svg/attributes.font_stretch\nsprocket/html/svg/attributes font_stretch","url":"sprocket/html/svg/attributes.html#font_stretch"},{"doc":"sprocket/html/svg/attributes","title":"font_style","content":"pub fn font_style(value: String) -&gt; Attribute\n The [SVG `font-style` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-style)\nSynonyms:\nsprocket/html/svg/attributes.font_style\nsprocket/html/svg/attributes font_style","url":"sprocket/html/svg/attributes.html#font_style"},{"doc":"sprocket/html/svg/attributes","title":"font_variant","content":"pub fn font_variant(value: String) -&gt; Attribute\n The [SVG `font-variant` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-variant)\nSynonyms:\nsprocket/html/svg/attributes.font_variant\nsprocket/html/svg/attributes font_variant","url":"sprocket/html/svg/attributes.html#font_variant"},{"doc":"sprocket/html/svg/attributes","title":"font_weight","content":"pub fn font_weight(value: String) -&gt; Attribute\n The [SVG `font-weight` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/font-weight)\nSynonyms:\nsprocket/html/svg/attributes.font_weight\nsprocket/html/svg/attributes font_weight","url":"sprocket/html/svg/attributes.html#font_weight"},{"doc":"sprocket/html/svg/attributes","title":"format","content":"pub fn format(value: String) -&gt; Attribute\n The [SVG `format` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/format)\nSynonyms:\nsprocket/html/svg/attributes.format\nsprocket/html/svg/attributes format","url":"sprocket/html/svg/attributes.html#format"},{"doc":"sprocket/html/svg/attributes","title":"fr","content":"pub fn fr(value: String) -&gt; Attribute\n The [SVG `fr` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/fr)\nSynonyms:\nsprocket/html/svg/attributes.fr\nsprocket/html/svg/attributes fr","url":"sprocket/html/svg/attributes.html#fr"},{"doc":"sprocket/html/svg/attributes","title":"from","content":"pub fn from(value: String) -&gt; Attribute\n The [SVG `from` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/from)\nSynonyms:\nsprocket/html/svg/attributes.from\nsprocket/html/svg/attributes from","url":"sprocket/html/svg/attributes.html#from"},{"doc":"sprocket/html/svg/attributes","title":"fx","content":"pub fn fx(value: String) -&gt; Attribute\n The [SVG `fx` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/fx)\nSynonyms:\nsprocket/html/svg/attributes.fx\nsprocket/html/svg/attributes fx","url":"sprocket/html/svg/attributes.html#fx"},{"doc":"sprocket/html/svg/attributes","title":"fy","content":"pub fn fy(value: String) -&gt; Attribute\n The [SVG `fy` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/fy)\nSynonyms:\nsprocket/html/svg/attributes.fy\nsprocket/html/svg/attributes fy","url":"sprocket/html/svg/attributes.html#fy"},{"doc":"sprocket/html/svg/attributes","title":"g1","content":"pub fn g1(value: String) -&gt; Attribute\n The [SVG `g1` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/g1)\nSynonyms:\nsprocket/html/svg/attributes.g1\nsprocket/html/svg/attributes g1","url":"sprocket/html/svg/attributes.html#g1"},{"doc":"sprocket/html/svg/attributes","title":"g2","content":"pub fn g2(value: String) -&gt; Attribute\n The [SVG `g2` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/g2)\nSynonyms:\nsprocket/html/svg/attributes.g2\nsprocket/html/svg/attributes g2","url":"sprocket/html/svg/attributes.html#g2"},{"doc":"sprocket/html/svg/attributes","title":"glyph_name","content":"pub fn glyph_name(value: String) -&gt; Attribute\n The [SVG `glyph-name` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/glyph-name)\nSynonyms:\nsprocket/html/svg/attributes.glyph_name\nsprocket/html/svg/attributes glyph_name","url":"sprocket/html/svg/attributes.html#glyph_name"},{"doc":"sprocket/html/svg/attributes","title":"glyph_orientation_horizontal","content":"pub fn glyph_orientation_horizontal(value: String) -&gt; Attribute\n The [SVG `glyph-orientation-horizontal` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/glyph-orientation-horizontal)\nSynonyms:\nsprocket/html/svg/attributes.glyph_orientation_horizontal\nsprocket/html/svg/attributes glyph_orientation_horizontal","url":"sprocket/html/svg/attributes.html#glyph_orientation_horizontal"},{"doc":"sprocket/html/svg/attributes","title":"glyph_orientation_vertical","content":"pub fn glyph_orientation_vertical(value: String) -&gt; Attribute\n The [SVG `glyph-orientation-vertical` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/glyph-orientation-vertical)\nSynonyms:\nsprocket/html/svg/attributes.glyph_orientation_vertical\nsprocket/html/svg/attributes glyph_orientation_vertical","url":"sprocket/html/svg/attributes.html#glyph_orientation_vertical"},{"doc":"sprocket/html/svg/attributes","title":"glyph_ref","content":"pub fn glyph_ref(value: String) -&gt; Attribute\n The [SVG `glyphRef` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/glyphRef)\nSynonyms:\nsprocket/html/svg/attributes.glyph_ref\nsprocket/html/svg/attributes glyph_ref","url":"sprocket/html/svg/attributes.html#glyph_ref"},{"doc":"sprocket/html/svg/attributes","title":"gradient_transform","content":"pub fn gradient_transform(value: String) -&gt; Attribute\n The [SVG `gradientTransform` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/gradientTransform)\nSynonyms:\nsprocket/html/svg/attributes.gradient_transform\nsprocket/html/svg/attributes gradient_transform","url":"sprocket/html/svg/attributes.html#gradient_transform"},{"doc":"sprocket/html/svg/attributes","title":"gradient_units","content":"pub fn gradient_units(value: String) -&gt; Attribute\n The [SVG `gradientUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/gradientUnits)\nSynonyms:\nsprocket/html/svg/attributes.gradient_units\nsprocket/html/svg/attributes gradient_units","url":"sprocket/html/svg/attributes.html#gradient_units"},{"doc":"sprocket/html/svg/attributes","title":"hanging","content":"pub fn hanging(value: String) -&gt; Attribute\n The [SVG `hanging` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/hanging)\nSynonyms:\nsprocket/html/svg/attributes.hanging\nsprocket/html/svg/attributes hanging","url":"sprocket/html/svg/attributes.html#hanging"},{"doc":"sprocket/html/svg/attributes","title":"height","content":"pub fn height(value: String) -&gt; Attribute\n The [SVG `height` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/height)\nSynonyms:\nsprocket/html/svg/attributes.height\nsprocket/html/svg/attributes height","url":"sprocket/html/svg/attributes.html#height"},{"doc":"sprocket/html/svg/attributes","title":"horiz_adv_x","content":"pub fn horiz_adv_x(value: String) -&gt; Attribute\n The [SVG `horiz-adv-x` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/horiz-adv-x)\nSynonyms:\nsprocket/html/svg/attributes.horiz_adv_x\nsprocket/html/svg/attributes horiz_adv_x","url":"sprocket/html/svg/attributes.html#horiz_adv_x"},{"doc":"sprocket/html/svg/attributes","title":"horiz_origin_x","content":"pub fn horiz_origin_x(value: String) -&gt; Attribute\n The [SVG `horiz-origin-x` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/horiz-origin-x)\nSynonyms:\nsprocket/html/svg/attributes.horiz_origin_x\nsprocket/html/svg/attributes horiz_origin_x","url":"sprocket/html/svg/attributes.html#horiz_origin_x"},{"doc":"sprocket/html/svg/attributes","title":"href","content":"pub fn href(value: String) -&gt; Attribute\n The [SVG `href` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/href)\nSynonyms:\nsprocket/html/svg/attributes.href\nsprocket/html/svg/attributes href","url":"sprocket/html/svg/attributes.html#href"},{"doc":"sprocket/html/svg/attributes","title":"hreflang","content":"pub fn hreflang(value: String) -&gt; Attribute\n The [SVG `hreflang` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/hreflang)\nSynonyms:\nsprocket/html/svg/attributes.hreflang\nsprocket/html/svg/attributes hreflang","url":"sprocket/html/svg/attributes.html#hreflang"},{"doc":"sprocket/html/svg/attributes","title":"id","content":"pub fn id(value: String) -&gt; Attribute\n The [SVG `id` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/id)\nSynonyms:\nsprocket/html/svg/attributes.id\nsprocket/html/svg/attributes id","url":"sprocket/html/svg/attributes.html#id"},{"doc":"sprocket/html/svg/attributes","title":"ideographic","content":"pub fn ideographic(value: String) -&gt; Attribute\n The [SVG `ideographic` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/ideographic)\nSynonyms:\nsprocket/html/svg/attributes.ideographic\nsprocket/html/svg/attributes ideographic","url":"sprocket/html/svg/attributes.html#ideographic"},{"doc":"sprocket/html/svg/attributes","title":"image_rendering","content":"pub fn image_rendering(value: String) -&gt; Attribute\n The [SVG `image-rendering` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/image-rendering)\nSynonyms:\nsprocket/html/svg/attributes.image_rendering\nsprocket/html/svg/attributes image_rendering","url":"sprocket/html/svg/attributes.html#image_rendering"},{"doc":"sprocket/html/svg/attributes","title":"in","content":"pub fn in(value: String) -&gt; Attribute\n The [SVG `in` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/in)\nSynonyms:\nsprocket/html/svg/attributes.in\nsprocket/html/svg/attributes in","url":"sprocket/html/svg/attributes.html#in"},{"doc":"sprocket/html/svg/attributes","title":"in2","content":"pub fn in2(value: String) -&gt; Attribute\n The [SVG `in2` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/in2)\nSynonyms:\nsprocket/html/svg/attributes.in2\nsprocket/html/svg/attributes in2","url":"sprocket/html/svg/attributes.html#in2"},{"doc":"sprocket/html/svg/attributes","title":"intercept","content":"pub fn intercept(value: String) -&gt; Attribute\n The [SVG `intercept` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/intercept)\nSynonyms:\nsprocket/html/svg/attributes.intercept\nsprocket/html/svg/attributes intercept","url":"sprocket/html/svg/attributes.html#intercept"},{"doc":"sprocket/html/svg/attributes","title":"k","content":"pub fn k(value: String) -&gt; Attribute\n The [SVG `k` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/k)\nSynonyms:\nsprocket/html/svg/attributes.k\nsprocket/html/svg/attributes k","url":"sprocket/html/svg/attributes.html#k"},{"doc":"sprocket/html/svg/attributes","title":"k1","content":"pub fn k1(value: String) -&gt; Attribute\n The [SVG `k1` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/k1)\nSynonyms:\nsprocket/html/svg/attributes.k1\nsprocket/html/svg/attributes k1","url":"sprocket/html/svg/attributes.html#k1"},{"doc":"sprocket/html/svg/attributes","title":"k2","content":"pub fn k2(value: String) -&gt; Attribute\n The [SVG `k2` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/k2)\nSynonyms:\nsprocket/html/svg/attributes.k2\nsprocket/html/svg/attributes k2","url":"sprocket/html/svg/attributes.html#k2"},{"doc":"sprocket/html/svg/attributes","title":"k3","content":"pub fn k3(value: String) -&gt; Attribute\n The [SVG `k3` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/k3)\nSynonyms:\nsprocket/html/svg/attributes.k3\nsprocket/html/svg/attributes k3","url":"sprocket/html/svg/attributes.html#k3"},{"doc":"sprocket/html/svg/attributes","title":"k4","content":"pub fn k4(value: String) -&gt; Attribute\n The [SVG `k4` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/k4)\nSynonyms:\nsprocket/html/svg/attributes.k4\nsprocket/html/svg/attributes k4","url":"sprocket/html/svg/attributes.html#k4"},{"doc":"sprocket/html/svg/attributes","title":"kernel_matrix","content":"pub fn kernel_matrix(value: String) -&gt; Attribute\n The [SVG `kernelMatrix` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/kernelMatrix)\nSynonyms:\nsprocket/html/svg/attributes.kernel_matrix\nsprocket/html/svg/attributes kernel_matrix","url":"sprocket/html/svg/attributes.html#kernel_matrix"},{"doc":"sprocket/html/svg/attributes","title":"kernel_unit_length","content":"pub fn kernel_unit_length(value: String) -&gt; Attribute\n The [SVG `kernelUnitLength` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/kernelUnitLength)\nSynonyms:\nsprocket/html/svg/attributes.kernel_unit_length\nsprocket/html/svg/attributes kernel_unit_length","url":"sprocket/html/svg/attributes.html#kernel_unit_length"},{"doc":"sprocket/html/svg/attributes","title":"kerning","content":"pub fn kerning(value: String) -&gt; Attribute\n The [SVG `kerning` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/kerning)\nSynonyms:\nsprocket/html/svg/attributes.kerning\nsprocket/html/svg/attributes kerning","url":"sprocket/html/svg/attributes.html#kerning"},{"doc":"sprocket/html/svg/attributes","title":"key_points","content":"pub fn key_points(value: String) -&gt; Attribute\n The [SVG `keyPoints` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/keyPoints)\nSynonyms:\nsprocket/html/svg/attributes.key_points\nsprocket/html/svg/attributes key_points","url":"sprocket/html/svg/attributes.html#key_points"},{"doc":"sprocket/html/svg/attributes","title":"key_splines","content":"pub fn key_splines(value: String) -&gt; Attribute\n The [SVG `keySplines` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/keySplines)\nSynonyms:\nsprocket/html/svg/attributes.key_splines\nsprocket/html/svg/attributes key_splines","url":"sprocket/html/svg/attributes.html#key_splines"},{"doc":"sprocket/html/svg/attributes","title":"key_times","content":"pub fn key_times(value: String) -&gt; Attribute\n The [SVG `keyTimes` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/keyTimes)\nSynonyms:\nsprocket/html/svg/attributes.key_times\nsprocket/html/svg/attributes key_times","url":"sprocket/html/svg/attributes.html#key_times"},{"doc":"sprocket/html/svg/attributes","title":"lang","content":"pub fn lang(value: String) -&gt; Attribute\n The [SVG `lang` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/lang)\nSynonyms:\nsprocket/html/svg/attributes.lang\nsprocket/html/svg/attributes lang","url":"sprocket/html/svg/attributes.html#lang"},{"doc":"sprocket/html/svg/attributes","title":"length_adjust","content":"pub fn length_adjust(value: String) -&gt; Attribute\n The [SVG `lengthAdjust` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/lengthAdjust)\nSynonyms:\nsprocket/html/svg/attributes.length_adjust\nsprocket/html/svg/attributes length_adjust","url":"sprocket/html/svg/attributes.html#length_adjust"},{"doc":"sprocket/html/svg/attributes","title":"letter_spacing","content":"pub fn letter_spacing(value: String) -&gt; Attribute\n The [SVG `letter-spacing` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/letter-spacing)\nSynonyms:\nsprocket/html/svg/attributes.letter_spacing\nsprocket/html/svg/attributes letter_spacing","url":"sprocket/html/svg/attributes.html#letter_spacing"},{"doc":"sprocket/html/svg/attributes","title":"lighting_color","content":"pub fn lighting_color(value: String) -&gt; Attribute\n The [SVG `lighting-color` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/lighting-color)\nSynonyms:\nsprocket/html/svg/attributes.lighting_color\nsprocket/html/svg/attributes lighting_color","url":"sprocket/html/svg/attributes.html#lighting_color"},{"doc":"sprocket/html/svg/attributes","title":"limiting_cone_angle","content":"pub fn limiting_cone_angle(value: String) -&gt; Attribute\n The [SVG `limitingConeAngle` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/limitingConeAngle)\nSynonyms:\nsprocket/html/svg/attributes.limiting_cone_angle\nsprocket/html/svg/attributes limiting_cone_angle","url":"sprocket/html/svg/attributes.html#limiting_cone_angle"},{"doc":"sprocket/html/svg/attributes","title":"local","content":"pub fn local(value: String) -&gt; Attribute\n The [SVG `local` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/local)\nSynonyms:\nsprocket/html/svg/attributes.local\nsprocket/html/svg/attributes local","url":"sprocket/html/svg/attributes.html#local"},{"doc":"sprocket/html/svg/attributes","title":"marker_end","content":"pub fn marker_end(value: String) -&gt; Attribute\n The [SVG `marker-end` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/marker-end)\nSynonyms:\nsprocket/html/svg/attributes.marker_end\nsprocket/html/svg/attributes marker_end","url":"sprocket/html/svg/attributes.html#marker_end"},{"doc":"sprocket/html/svg/attributes","title":"marker_height","content":"pub fn marker_height(value: String) -&gt; Attribute\n The [SVG `markerHeight` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/markerHeight)\nSynonyms:\nsprocket/html/svg/attributes.marker_height\nsprocket/html/svg/attributes marker_height","url":"sprocket/html/svg/attributes.html#marker_height"},{"doc":"sprocket/html/svg/attributes","title":"marker_mid","content":"pub fn marker_mid(value: String) -&gt; Attribute\n The [SVG `marker-mid` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/marker-mid)\nSynonyms:\nsprocket/html/svg/attributes.marker_mid\nsprocket/html/svg/attributes marker_mid","url":"sprocket/html/svg/attributes.html#marker_mid"},{"doc":"sprocket/html/svg/attributes","title":"marker_start","content":"pub fn marker_start(value: String) -&gt; Attribute\n The [SVG `marker-start` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/marker-start)\nSynonyms:\nsprocket/html/svg/attributes.marker_start\nsprocket/html/svg/attributes marker_start","url":"sprocket/html/svg/attributes.html#marker_start"},{"doc":"sprocket/html/svg/attributes","title":"marker_units","content":"pub fn marker_units(value: String) -&gt; Attribute\n The [SVG `markerUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/markerUnits)\nSynonyms:\nsprocket/html/svg/attributes.marker_units\nsprocket/html/svg/attributes marker_units","url":"sprocket/html/svg/attributes.html#marker_units"},{"doc":"sprocket/html/svg/attributes","title":"marker_width","content":"pub fn marker_width(value: String) -&gt; Attribute\n The [SVG `markerWidth` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/markerWidth)\nSynonyms:\nsprocket/html/svg/attributes.marker_width\nsprocket/html/svg/attributes marker_width","url":"sprocket/html/svg/attributes.html#marker_width"},{"doc":"sprocket/html/svg/attributes","title":"mask","content":"pub fn mask(value: String) -&gt; Attribute\n The [SVG `mask` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/mask)\nSynonyms:\nsprocket/html/svg/attributes.mask\nsprocket/html/svg/attributes mask","url":"sprocket/html/svg/attributes.html#mask"},{"doc":"sprocket/html/svg/attributes","title":"mask_content_units","content":"pub fn mask_content_units(value: String) -&gt; Attribute\n The [SVG `maskContentUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/maskContentUnits)\nSynonyms:\nsprocket/html/svg/attributes.mask_content_units\nsprocket/html/svg/attributes mask_content_units","url":"sprocket/html/svg/attributes.html#mask_content_units"},{"doc":"sprocket/html/svg/attributes","title":"mask_units","content":"pub fn mask_units(value: String) -&gt; Attribute\n The [SVG `maskUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/maskUnits)\nSynonyms:\nsprocket/html/svg/attributes.mask_units\nsprocket/html/svg/attributes mask_units","url":"sprocket/html/svg/attributes.html#mask_units"},{"doc":"sprocket/html/svg/attributes","title":"mathematical","content":"pub fn mathematical(value: String) -&gt; Attribute\n The [SVG `mathematical` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/mathematical)\nSynonyms:\nsprocket/html/svg/attributes.mathematical\nsprocket/html/svg/attributes mathematical","url":"sprocket/html/svg/attributes.html#mathematical"},{"doc":"sprocket/html/svg/attributes","title":"max","content":"pub fn max(value: String) -&gt; Attribute\n The [SVG `max` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/max)\nSynonyms:\nsprocket/html/svg/attributes.max\nsprocket/html/svg/attributes max","url":"sprocket/html/svg/attributes.html#max"},{"doc":"sprocket/html/svg/attributes","title":"media","content":"pub fn media(value: String) -&gt; Attribute\n The [SVG `media` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/media)\nSynonyms:\nsprocket/html/svg/attributes.media\nsprocket/html/svg/attributes media","url":"sprocket/html/svg/attributes.html#media"},{"doc":"sprocket/html/svg/attributes","title":"method","content":"pub fn method(value: String) -&gt; Attribute\n The [SVG `method` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/method)\nSynonyms:\nsprocket/html/svg/attributes.method\nsprocket/html/svg/attributes method","url":"sprocket/html/svg/attributes.html#method"},{"doc":"sprocket/html/svg/attributes","title":"min","content":"pub fn min(value: String) -&gt; Attribute\n The [SVG `min` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/min)\nSynonyms:\nsprocket/html/svg/attributes.min\nsprocket/html/svg/attributes min","url":"sprocket/html/svg/attributes.html#min"},{"doc":"sprocket/html/svg/attributes","title":"mode","content":"pub fn mode(value: String) -&gt; Attribute\n The [SVG `mode` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/mode)\nSynonyms:\nsprocket/html/svg/attributes.mode\nsprocket/html/svg/attributes mode","url":"sprocket/html/svg/attributes.html#mode"},{"doc":"sprocket/html/svg/attributes","title":"name","content":"pub fn name(value: String) -&gt; Attribute\n The [SVG `name` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/name)\nSynonyms:\nsprocket/html/svg/attributes.name\nsprocket/html/svg/attributes name","url":"sprocket/html/svg/attributes.html#name"},{"doc":"sprocket/html/svg/attributes","title":"num_octaves","content":"pub fn num_octaves(value: String) -&gt; Attribute\n The [SVG `numOctaves` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/numOctaves)\nSynonyms:\nsprocket/html/svg/attributes.num_octaves\nsprocket/html/svg/attributes num_octaves","url":"sprocket/html/svg/attributes.html#num_octaves"},{"doc":"sprocket/html/svg/attributes","title":"offset","content":"pub fn offset(value: String) -&gt; Attribute\n The [SVG `offset` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/offset)\nSynonyms:\nsprocket/html/svg/attributes.offset\nsprocket/html/svg/attributes offset","url":"sprocket/html/svg/attributes.html#offset"},{"doc":"sprocket/html/svg/attributes","title":"opacity","content":"pub fn opacity(value: String) -&gt; Attribute\n The [SVG `opacity` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/opacity)\nSynonyms:\nsprocket/html/svg/attributes.opacity\nsprocket/html/svg/attributes opacity","url":"sprocket/html/svg/attributes.html#opacity"},{"doc":"sprocket/html/svg/attributes","title":"operator","content":"pub fn operator(value: String) -&gt; Attribute\n The [SVG `operator` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/operator)\nSynonyms:\nsprocket/html/svg/attributes.operator\nsprocket/html/svg/attributes operator","url":"sprocket/html/svg/attributes.html#operator"},{"doc":"sprocket/html/svg/attributes","title":"order","content":"pub fn order(value: String) -&gt; Attribute\n The [SVG `order` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/order)\nSynonyms:\nsprocket/html/svg/attributes.order\nsprocket/html/svg/attributes order","url":"sprocket/html/svg/attributes.html#order"},{"doc":"sprocket/html/svg/attributes","title":"orient","content":"pub fn orient(value: String) -&gt; Attribute\n The [SVG `orient` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/orient)\nSynonyms:\nsprocket/html/svg/attributes.orient\nsprocket/html/svg/attributes orient","url":"sprocket/html/svg/attributes.html#orient"},{"doc":"sprocket/html/svg/attributes","title":"orientation","content":"pub fn orientation(value: String) -&gt; Attribute\n The [SVG `orientation` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/orientation)\nSynonyms:\nsprocket/html/svg/attributes.orientation\nsprocket/html/svg/attributes orientation","url":"sprocket/html/svg/attributes.html#orientation"},{"doc":"sprocket/html/svg/attributes","title":"origin","content":"pub fn origin(value: String) -&gt; Attribute\n The [SVG `origin` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/origin)\nSynonyms:\nsprocket/html/svg/attributes.origin\nsprocket/html/svg/attributes origin","url":"sprocket/html/svg/attributes.html#origin"},{"doc":"sprocket/html/svg/attributes","title":"overflow","content":"pub fn overflow(value: String) -&gt; Attribute\n The [SVG `overflow` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/overflow)\nSynonyms:\nsprocket/html/svg/attributes.overflow\nsprocket/html/svg/attributes overflow","url":"sprocket/html/svg/attributes.html#overflow"},{"doc":"sprocket/html/svg/attributes","title":"overline_position","content":"pub fn overline_position(value: String) -&gt; Attribute\n The [SVG `overline-position` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/overline-position)\nSynonyms:\nsprocket/html/svg/attributes.overline_position\nsprocket/html/svg/attributes overline_position","url":"sprocket/html/svg/attributes.html#overline_position"},{"doc":"sprocket/html/svg/attributes","title":"overline_thickness","content":"pub fn overline_thickness(value: String) -&gt; Attribute\n The [SVG `overline-thickness` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/overline-thickness)\nSynonyms:\nsprocket/html/svg/attributes.overline_thickness\nsprocket/html/svg/attributes overline_thickness","url":"sprocket/html/svg/attributes.html#overline_thickness"},{"doc":"sprocket/html/svg/attributes","title":"paint_order","content":"pub fn paint_order(value: String) -&gt; Attribute\n The [SVG `paint-order` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/paint-order)\nSynonyms:\nsprocket/html/svg/attributes.paint_order\nsprocket/html/svg/attributes paint_order","url":"sprocket/html/svg/attributes.html#paint_order"},{"doc":"sprocket/html/svg/attributes","title":"panose_1","content":"pub fn panose_1(value: String) -&gt; Attribute\n The [SVG `panose-1` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/panose-1)\nSynonyms:\nsprocket/html/svg/attributes.panose_1\nsprocket/html/svg/attributes panose_1","url":"sprocket/html/svg/attributes.html#panose_1"},{"doc":"sprocket/html/svg/attributes","title":"path","content":"pub fn path(value: String) -&gt; Attribute\n The [SVG `path` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/path)\nSynonyms:\nsprocket/html/svg/attributes.path\nsprocket/html/svg/attributes path","url":"sprocket/html/svg/attributes.html#path"},{"doc":"sprocket/html/svg/attributes","title":"path_length","content":"pub fn path_length(value: String) -&gt; Attribute\n The [SVG `pathLength` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/pathLength)\nSynonyms:\nsprocket/html/svg/attributes.path_length\nsprocket/html/svg/attributes path_length","url":"sprocket/html/svg/attributes.html#path_length"},{"doc":"sprocket/html/svg/attributes","title":"pattern_content_units","content":"pub fn pattern_content_units(value: String) -&gt; Attribute\n The [SVG `patternContentUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/patternContentUnits)\nSynonyms:\nsprocket/html/svg/attributes.pattern_content_units\nsprocket/html/svg/attributes pattern_content_units","url":"sprocket/html/svg/attributes.html#pattern_content_units"},{"doc":"sprocket/html/svg/attributes","title":"pattern_transform","content":"pub fn pattern_transform(value: String) -&gt; Attribute\n The [SVG `patternTransform` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/patternTransform)\nSynonyms:\nsprocket/html/svg/attributes.pattern_transform\nsprocket/html/svg/attributes pattern_transform","url":"sprocket/html/svg/attributes.html#pattern_transform"},{"doc":"sprocket/html/svg/attributes","title":"pattern_units","content":"pub fn pattern_units(value: String) -&gt; Attribute\n The [SVG `patternUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/patternUnits)\nSynonyms:\nsprocket/html/svg/attributes.pattern_units\nsprocket/html/svg/attributes pattern_units","url":"sprocket/html/svg/attributes.html#pattern_units"},{"doc":"sprocket/html/svg/attributes","title":"ping","content":"pub fn ping(value: String) -&gt; Attribute\n The [SVG `ping` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/ping)\nSynonyms:\nsprocket/html/svg/attributes.ping\nsprocket/html/svg/attributes ping","url":"sprocket/html/svg/attributes.html#ping"},{"doc":"sprocket/html/svg/attributes","title":"pointer_events","content":"pub fn pointer_events(value: String) -&gt; Attribute\n The [SVG `pointer-events` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/pointer-events)\nSynonyms:\nsprocket/html/svg/attributes.pointer_events\nsprocket/html/svg/attributes pointer_events","url":"sprocket/html/svg/attributes.html#pointer_events"},{"doc":"sprocket/html/svg/attributes","title":"points","content":"pub fn points(value: String) -&gt; Attribute\n The [SVG `points` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/points)\nSynonyms:\nsprocket/html/svg/attributes.points\nsprocket/html/svg/attributes points","url":"sprocket/html/svg/attributes.html#points"},{"doc":"sprocket/html/svg/attributes","title":"points_at_x","content":"pub fn points_at_x(value: String) -&gt; Attribute\n The [SVG `pointsAtX` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/pointsAtX)\nSynonyms:\nsprocket/html/svg/attributes.points_at_x\nsprocket/html/svg/attributes points_at_x","url":"sprocket/html/svg/attributes.html#points_at_x"},{"doc":"sprocket/html/svg/attributes","title":"points_at_y","content":"pub fn points_at_y(value: String) -&gt; Attribute\n The [SVG `pointsAtY` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/pointsAtY)\nSynonyms:\nsprocket/html/svg/attributes.points_at_y\nsprocket/html/svg/attributes points_at_y","url":"sprocket/html/svg/attributes.html#points_at_y"},{"doc":"sprocket/html/svg/attributes","title":"points_at_z","content":"pub fn points_at_z(value: String) -&gt; Attribute\n The [SVG `pointsAtZ` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/pointsAtZ)\nSynonyms:\nsprocket/html/svg/attributes.points_at_z\nsprocket/html/svg/attributes points_at_z","url":"sprocket/html/svg/attributes.html#points_at_z"},{"doc":"sprocket/html/svg/attributes","title":"preserve_alpha","content":"pub fn preserve_alpha(value: String) -&gt; Attribute\n The [SVG `preserveAlpha` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/preserveAlpha)\nSynonyms:\nsprocket/html/svg/attributes.preserve_alpha\nsprocket/html/svg/attributes preserve_alpha","url":"sprocket/html/svg/attributes.html#preserve_alpha"},{"doc":"sprocket/html/svg/attributes","title":"preserve_aspect_ratio","content":"pub fn preserve_aspect_ratio(value: String) -&gt; Attribute\n The [SVG `preserveAspectRatio` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/preserveAspectRatio)\nSynonyms:\nsprocket/html/svg/attributes.preserve_aspect_ratio\nsprocket/html/svg/attributes preserve_aspect_ratio","url":"sprocket/html/svg/attributes.html#preserve_aspect_ratio"},{"doc":"sprocket/html/svg/attributes","title":"primitive_units","content":"pub fn primitive_units(value: String) -&gt; Attribute\n The [SVG `primitiveUnits` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/primitiveUnits)\nSynonyms:\nsprocket/html/svg/attributes.primitive_units\nsprocket/html/svg/attributes primitive_units","url":"sprocket/html/svg/attributes.html#primitive_units"},{"doc":"sprocket/html/svg/attributes","title":"r","content":"pub fn r(value: String) -&gt; Attribute\n The [SVG `r` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/r)\nSynonyms:\nsprocket/html/svg/attributes.r\nsprocket/html/svg/attributes r","url":"sprocket/html/svg/attributes.html#r"},{"doc":"sprocket/html/svg/attributes","title":"radius","content":"pub fn radius(value: String) -&gt; Attribute\n The [SVG `radius` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/radius)\nSynonyms:\nsprocket/html/svg/attributes.radius\nsprocket/html/svg/attributes radius","url":"sprocket/html/svg/attributes.html#radius"},{"doc":"sprocket/html/svg/attributes","title":"ref_x","content":"pub fn ref_x(value: String) -&gt; Attribute\n The [SVG `refX` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/refX)\nSynonyms:\nsprocket/html/svg/attributes.ref_x\nsprocket/html/svg/attributes ref_x","url":"sprocket/html/svg/attributes.html#ref_x"},{"doc":"sprocket/html/svg/attributes","title":"ref_y","content":"pub fn ref_y(value: String) -&gt; Attribute\n The [SVG `refY` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/refY)\nSynonyms:\nsprocket/html/svg/attributes.ref_y\nsprocket/html/svg/attributes ref_y","url":"sprocket/html/svg/attributes.html#ref_y"},{"doc":"sprocket/html/svg/attributes","title":"referrer_policy","content":"pub fn referrer_policy(value: String) -&gt; Attribute\n The [SVG `referrerPolicy` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/referrerPolicy)\nSynonyms:\nsprocket/html/svg/attributes.referrer_policy\nsprocket/html/svg/attributes referrer_policy","url":"sprocket/html/svg/attributes.html#referrer_policy"},{"doc":"sprocket/html/svg/attributes","title":"rel","content":"pub fn rel(value: String) -&gt; Attribute\n The [SVG `rel` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/rel)\nSynonyms:\nsprocket/html/svg/attributes.rel\nsprocket/html/svg/attributes rel","url":"sprocket/html/svg/attributes.html#rel"},{"doc":"sprocket/html/svg/attributes","title":"rendering_intent","content":"pub fn rendering_intent(value: String) -&gt; Attribute\n The [SVG `rendering-intent` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/rendering-intent)\nSynonyms:\nsprocket/html/svg/attributes.rendering_intent\nsprocket/html/svg/attributes rendering_intent","url":"sprocket/html/svg/attributes.html#rendering_intent"},{"doc":"sprocket/html/svg/attributes","title":"repeat_count","content":"pub fn repeat_count(value: String) -&gt; Attribute\n The [SVG `repeatCount` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/repeatCount)\nSynonyms:\nsprocket/html/svg/attributes.repeat_count\nsprocket/html/svg/attributes repeat_count","url":"sprocket/html/svg/attributes.html#repeat_count"},{"doc":"sprocket/html/svg/attributes","title":"repeat_dur","content":"pub fn repeat_dur(value: String) -&gt; Attribute\n The [SVG `repeatDur` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/repeatDur)\nSynonyms:\nsprocket/html/svg/attributes.repeat_dur\nsprocket/html/svg/attributes repeat_dur","url":"sprocket/html/svg/attributes.html#repeat_dur"},{"doc":"sprocket/html/svg/attributes","title":"required_extensions","content":"pub fn required_extensions(value: String) -&gt; Attribute\n The [SVG `requiredExtensions` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/requiredExtensions)\nSynonyms:\nsprocket/html/svg/attributes.required_extensions\nsprocket/html/svg/attributes required_extensions","url":"sprocket/html/svg/attributes.html#required_extensions"},{"doc":"sprocket/html/svg/attributes","title":"required_features","content":"pub fn required_features(value: String) -&gt; Attribute\n The [SVG `requiredFeatures` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/requiredFeatures)\nSynonyms:\nsprocket/html/svg/attributes.required_features\nsprocket/html/svg/attributes required_features","url":"sprocket/html/svg/attributes.html#required_features"},{"doc":"sprocket/html/svg/attributes","title":"restart","content":"pub fn restart(value: String) -&gt; Attribute\n The [SVG `restart` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/restart)\nSynonyms:\nsprocket/html/svg/attributes.restart\nsprocket/html/svg/attributes restart","url":"sprocket/html/svg/attributes.html#restart"},{"doc":"sprocket/html/svg/attributes","title":"result","content":"pub fn result(value: String) -&gt; Attribute\n The [SVG `result` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/result)\nSynonyms:\nsprocket/html/svg/attributes.result\nsprocket/html/svg/attributes result","url":"sprocket/html/svg/attributes.html#result"},{"doc":"sprocket/html/svg/attributes","title":"rotate","content":"pub fn rotate(value: String) -&gt; Attribute\n The [SVG `rotate` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/rotate)\nSynonyms:\nsprocket/html/svg/attributes.rotate\nsprocket/html/svg/attributes rotate","url":"sprocket/html/svg/attributes.html#rotate"},{"doc":"sprocket/html/svg/attributes","title":"rx","content":"pub fn rx(value: String) -&gt; Attribute\n The [SVG `rx` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/rx)\nSynonyms:\nsprocket/html/svg/attributes.rx\nsprocket/html/svg/attributes rx","url":"sprocket/html/svg/attributes.html#rx"},{"doc":"sprocket/html/svg/attributes","title":"ry","content":"pub fn ry(value: String) -&gt; Attribute\n The [SVG `ry` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/ry)\nSynonyms:\nsprocket/html/svg/attributes.ry\nsprocket/html/svg/attributes ry","url":"sprocket/html/svg/attributes.html#ry"},{"doc":"sprocket/html/svg/attributes","title":"scale","content":"pub fn scale(value: String) -&gt; Attribute\n The [SVG `scale` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/scale)\nSynonyms:\nsprocket/html/svg/attributes.scale\nsprocket/html/svg/attributes scale","url":"sprocket/html/svg/attributes.html#scale"},{"doc":"sprocket/html/svg/attributes","title":"seed","content":"pub fn seed(value: String) -&gt; Attribute\n The [SVG `seed` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/seed)\nSynonyms:\nsprocket/html/svg/attributes.seed\nsprocket/html/svg/attributes seed","url":"sprocket/html/svg/attributes.html#seed"},{"doc":"sprocket/html/svg/attributes","title":"shape_rendering","content":"pub fn shape_rendering(value: String) -&gt; Attribute\n The [SVG `shape-rendering` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/shape-rendering)\nSynonyms:\nsprocket/html/svg/attributes.shape_rendering\nsprocket/html/svg/attributes shape_rendering","url":"sprocket/html/svg/attributes.html#shape_rendering"},{"doc":"sprocket/html/svg/attributes","title":"slope","content":"pub fn slope(value: String) -&gt; Attribute\n The [SVG `slope` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/slope)\nSynonyms:\nsprocket/html/svg/attributes.slope\nsprocket/html/svg/attributes slope","url":"sprocket/html/svg/attributes.html#slope"},{"doc":"sprocket/html/svg/attributes","title":"spacing","content":"pub fn spacing(value: String) -&gt; Attribute\n The [SVG `spacing` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/spacing)\nSynonyms:\nsprocket/html/svg/attributes.spacing\nsprocket/html/svg/attributes spacing","url":"sprocket/html/svg/attributes.html#spacing"},{"doc":"sprocket/html/svg/attributes","title":"specular_constant","content":"pub fn specular_constant(value: String) -&gt; Attribute\n The [SVG `specularConstant` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/specularConstant)\nSynonyms:\nsprocket/html/svg/attributes.specular_constant\nsprocket/html/svg/attributes specular_constant","url":"sprocket/html/svg/attributes.html#specular_constant"},{"doc":"sprocket/html/svg/attributes","title":"specular_exponent","content":"pub fn specular_exponent(value: String) -&gt; Attribute\n The [SVG `specularExponent` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/specularExponent)\nSynonyms:\nsprocket/html/svg/attributes.specular_exponent\nsprocket/html/svg/attributes specular_exponent","url":"sprocket/html/svg/attributes.html#specular_exponent"},{"doc":"sprocket/html/svg/attributes","title":"speed","content":"pub fn speed(value: String) -&gt; Attribute\n The [SVG `speed` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/speed)\nSynonyms:\nsprocket/html/svg/attributes.speed\nsprocket/html/svg/attributes speed","url":"sprocket/html/svg/attributes.html#speed"},{"doc":"sprocket/html/svg/attributes","title":"spread_method","content":"pub fn spread_method(value: String) -&gt; Attribute\n The [SVG `spreadMethod` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/spreadMethod)\nSynonyms:\nsprocket/html/svg/attributes.spread_method\nsprocket/html/svg/attributes spread_method","url":"sprocket/html/svg/attributes.html#spread_method"},{"doc":"sprocket/html/svg/attributes","title":"start_offset","content":"pub fn start_offset(value: String) -&gt; Attribute\n The [SVG `startOffset` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/startOffset)\nSynonyms:\nsprocket/html/svg/attributes.start_offset\nsprocket/html/svg/attributes start_offset","url":"sprocket/html/svg/attributes.html#start_offset"},{"doc":"sprocket/html/svg/attributes","title":"std_deviation","content":"pub fn std_deviation(value: String) -&gt; Attribute\n The [SVG `stdDeviation` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stdDeviation)\nSynonyms:\nsprocket/html/svg/attributes.std_deviation\nsprocket/html/svg/attributes std_deviation","url":"sprocket/html/svg/attributes.html#std_deviation"},{"doc":"sprocket/html/svg/attributes","title":"stemh","content":"pub fn stemh(value: String) -&gt; Attribute\n The [SVG `stemh` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stemh)\nSynonyms:\nsprocket/html/svg/attributes.stemh\nsprocket/html/svg/attributes stemh","url":"sprocket/html/svg/attributes.html#stemh"},{"doc":"sprocket/html/svg/attributes","title":"stemv","content":"pub fn stemv(value: String) -&gt; Attribute\n The [SVG `stemv` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stemv)\nSynonyms:\nsprocket/html/svg/attributes.stemv\nsprocket/html/svg/attributes stemv","url":"sprocket/html/svg/attributes.html#stemv"},{"doc":"sprocket/html/svg/attributes","title":"stitch_tiles","content":"pub fn stitch_tiles(value: String) -&gt; Attribute\n The [SVG `stitchTiles` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stitchTiles)\nSynonyms:\nsprocket/html/svg/attributes.stitch_tiles\nsprocket/html/svg/attributes stitch_tiles","url":"sprocket/html/svg/attributes.html#stitch_tiles"},{"doc":"sprocket/html/svg/attributes","title":"stop_color","content":"pub fn stop_color(value: String) -&gt; Attribute\n The [SVG `stop-color` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stop-color)\nSynonyms:\nsprocket/html/svg/attributes.stop_color\nsprocket/html/svg/attributes stop_color","url":"sprocket/html/svg/attributes.html#stop_color"},{"doc":"sprocket/html/svg/attributes","title":"stop_opacity","content":"pub fn stop_opacity(value: String) -&gt; Attribute\n The [SVG `stop-opacity` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stop-opacity)\nSynonyms:\nsprocket/html/svg/attributes.stop_opacity\nsprocket/html/svg/attributes stop_opacity","url":"sprocket/html/svg/attributes.html#stop_opacity"},{"doc":"sprocket/html/svg/attributes","title":"strikethrough_position","content":"pub fn strikethrough_position(value: String) -&gt; Attribute\n The [SVG `strikethrough-position` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/strikethrough-position)\nSynonyms:\nsprocket/html/svg/attributes.strikethrough_position\nsprocket/html/svg/attributes strikethrough_position","url":"sprocket/html/svg/attributes.html#strikethrough_position"},{"doc":"sprocket/html/svg/attributes","title":"strikethrough_thickness","content":"pub fn strikethrough_thickness(value: String) -&gt; Attribute\n The [SVG `strikethrough-thickness` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/strikethrough-thickness)\nSynonyms:\nsprocket/html/svg/attributes.strikethrough_thickness\nsprocket/html/svg/attributes strikethrough_thickness","url":"sprocket/html/svg/attributes.html#strikethrough_thickness"},{"doc":"sprocket/html/svg/attributes","title":"string","content":"pub fn string(value: String) -&gt; Attribute\n The [SVG `string` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/string)\nSynonyms:\nsprocket/html/svg/attributes.string\nsprocket/html/svg/attributes string","url":"sprocket/html/svg/attributes.html#string"},{"doc":"sprocket/html/svg/attributes","title":"stroke","content":"pub fn stroke(value: String) -&gt; Attribute\n The [SVG `stroke` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke)\nSynonyms:\nsprocket/html/svg/attributes.stroke\nsprocket/html/svg/attributes stroke","url":"sprocket/html/svg/attributes.html#stroke"},{"doc":"sprocket/html/svg/attributes","title":"stroke_dasharray","content":"pub fn stroke_dasharray(value: String) -&gt; Attribute\n The [SVG `stroke-dasharray` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-dasharray)\nSynonyms:\nsprocket/html/svg/attributes.stroke_dasharray\nsprocket/html/svg/attributes stroke_dasharray","url":"sprocket/html/svg/attributes.html#stroke_dasharray"},{"doc":"sprocket/html/svg/attributes","title":"stroke_dashoffset","content":"pub fn stroke_dashoffset(value: String) -&gt; Attribute\n The [SVG `stroke-dashoffset` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-dashoffset)\nSynonyms:\nsprocket/html/svg/attributes.stroke_dashoffset\nsprocket/html/svg/attributes stroke_dashoffset","url":"sprocket/html/svg/attributes.html#stroke_dashoffset"},{"doc":"sprocket/html/svg/attributes","title":"stroke_linecap","content":"pub fn stroke_linecap(value: String) -&gt; Attribute\n The [SVG `stroke-linecap` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-linecap)\nSynonyms:\nsprocket/html/svg/attributes.stroke_linecap\nsprocket/html/svg/attributes stroke_linecap","url":"sprocket/html/svg/attributes.html#stroke_linecap"},{"doc":"sprocket/html/svg/attributes","title":"stroke_linejoin","content":"pub fn stroke_linejoin(value: String) -&gt; Attribute\n The [SVG `stroke-linejoin` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-linejoin)\nSynonyms:\nsprocket/html/svg/attributes.stroke_linejoin\nsprocket/html/svg/attributes stroke_linejoin","url":"sprocket/html/svg/attributes.html#stroke_linejoin"},{"doc":"sprocket/html/svg/attributes","title":"stroke_miterlimit","content":"pub fn stroke_miterlimit(value: String) -&gt; Attribute\n The [SVG `stroke-miterlimit` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-miterlimit)\nSynonyms:\nsprocket/html/svg/attributes.stroke_miterlimit\nsprocket/html/svg/attributes stroke_miterlimit","url":"sprocket/html/svg/attributes.html#stroke_miterlimit"},{"doc":"sprocket/html/svg/attributes","title":"stroke_opacity","content":"pub fn stroke_opacity(value: String) -&gt; Attribute\n The [SVG `stroke-opacity` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-opacity)\nSynonyms:\nsprocket/html/svg/attributes.stroke_opacity\nsprocket/html/svg/attributes stroke_opacity","url":"sprocket/html/svg/attributes.html#stroke_opacity"},{"doc":"sprocket/html/svg/attributes","title":"stroke_width","content":"pub fn stroke_width(value: String) -&gt; Attribute\n The [SVG `stroke-width` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/stroke-width)\nSynonyms:\nsprocket/html/svg/attributes.stroke_width\nsprocket/html/svg/attributes stroke_width","url":"sprocket/html/svg/attributes.html#stroke_width"},{"doc":"sprocket/html/svg/attributes","title":"style","content":"pub fn style(value: String) -&gt; Attribute\n The [SVG `style` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/style)\nSynonyms:\nsprocket/html/svg/attributes.style\nsprocket/html/svg/attributes style","url":"sprocket/html/svg/attributes.html#style"},{"doc":"sprocket/html/svg/attributes","title":"surface_scale","content":"pub fn surface_scale(value: String) -&gt; Attribute\n The [SVG `surfaceScale` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/surfaceScale)\nSynonyms:\nsprocket/html/svg/attributes.surface_scale\nsprocket/html/svg/attributes surface_scale","url":"sprocket/html/svg/attributes.html#surface_scale"},{"doc":"sprocket/html/svg/attributes","title":"system_language","content":"pub fn system_language(value: String) -&gt; Attribute\n The [SVG `systemLanguage` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/systemLanguage)\nSynonyms:\nsprocket/html/svg/attributes.system_language\nsprocket/html/svg/attributes system_language","url":"sprocket/html/svg/attributes.html#system_language"},{"doc":"sprocket/html/svg/attributes","title":"tabindex","content":"pub fn tabindex(value: String) -&gt; Attribute\n The [SVG `tabindex` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/tabindex)\nSynonyms:\nsprocket/html/svg/attributes.tabindex\nsprocket/html/svg/attributes tabindex","url":"sprocket/html/svg/attributes.html#tabindex"},{"doc":"sprocket/html/svg/attributes","title":"table_values","content":"pub fn table_values(value: String) -&gt; Attribute\n The [SVG `tableValues` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/tableValues)\nSynonyms:\nsprocket/html/svg/attributes.table_values\nsprocket/html/svg/attributes table_values","url":"sprocket/html/svg/attributes.html#table_values"},{"doc":"sprocket/html/svg/attributes","title":"target","content":"pub fn target(value: String) -&gt; Attribute\n The [SVG `target` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/target)\nSynonyms:\nsprocket/html/svg/attributes.target\nsprocket/html/svg/attributes target","url":"sprocket/html/svg/attributes.html#target"},{"doc":"sprocket/html/svg/attributes","title":"target_x","content":"pub fn target_x(value: String) -&gt; Attribute\n The [SVG `targetX` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/targetX)\nSynonyms:\nsprocket/html/svg/attributes.target_x\nsprocket/html/svg/attributes target_x","url":"sprocket/html/svg/attributes.html#target_x"},{"doc":"sprocket/html/svg/attributes","title":"target_y","content":"pub fn target_y(value: String) -&gt; Attribute\n The [SVG `targetY` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/targetY)\nSynonyms:\nsprocket/html/svg/attributes.target_y\nsprocket/html/svg/attributes target_y","url":"sprocket/html/svg/attributes.html#target_y"},{"doc":"sprocket/html/svg/attributes","title":"text_anchor","content":"pub fn text_anchor(value: String) -&gt; Attribute\n The [SVG `text-anchor` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/text-anchor)\nSynonyms:\nsprocket/html/svg/attributes.text_anchor\nsprocket/html/svg/attributes text_anchor","url":"sprocket/html/svg/attributes.html#text_anchor"},{"doc":"sprocket/html/svg/attributes","title":"text_decoration","content":"pub fn text_decoration(value: String) -&gt; Attribute\n The [SVG `text-decoration` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/text-decoration)\nSynonyms:\nsprocket/html/svg/attributes.text_decoration\nsprocket/html/svg/attributes text_decoration","url":"sprocket/html/svg/attributes.html#text_decoration"},{"doc":"sprocket/html/svg/attributes","title":"text_length","content":"pub fn text_length(value: String) -&gt; Attribute\n The [SVG `textLength` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/textLength)\nSynonyms:\nsprocket/html/svg/attributes.text_length\nsprocket/html/svg/attributes text_length","url":"sprocket/html/svg/attributes.html#text_length"},{"doc":"sprocket/html/svg/attributes","title":"text_rendering","content":"pub fn text_rendering(value: String) -&gt; Attribute\n The [SVG `text-rendering` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/text-rendering)\nSynonyms:\nsprocket/html/svg/attributes.text_rendering\nsprocket/html/svg/attributes text_rendering","url":"sprocket/html/svg/attributes.html#text_rendering"},{"doc":"sprocket/html/svg/attributes","title":"to","content":"pub fn to(value: String) -&gt; Attribute\n The [SVG `to` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/to)\nSynonyms:\nsprocket/html/svg/attributes.to\nsprocket/html/svg/attributes to","url":"sprocket/html/svg/attributes.html#to"},{"doc":"sprocket/html/svg/attributes","title":"transform","content":"pub fn transform(value: String) -&gt; Attribute\n The [SVG `transform` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/transform)\nSynonyms:\nsprocket/html/svg/attributes.transform\nsprocket/html/svg/attributes transform","url":"sprocket/html/svg/attributes.html#transform"},{"doc":"sprocket/html/svg/attributes","title":"transform_origin","content":"pub fn transform_origin(value: String) -&gt; Attribute\n The [SVG `transform-origin` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/transform-origin)\nSynonyms:\nsprocket/html/svg/attributes.transform_origin\nsprocket/html/svg/attributes transform_origin","url":"sprocket/html/svg/attributes.html#transform_origin"},{"doc":"sprocket/html/svg/attributes","title":"type_","content":"pub fn type_(value: String) -&gt; Attribute\n The [SVG `type` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/type)\nSynonyms:\nsprocket/html/svg/attributes.type_\nsprocket/html/svg/attributes type_","url":"sprocket/html/svg/attributes.html#type_"},{"doc":"sprocket/html/svg/attributes","title":"u1","content":"pub fn u1(value: String) -&gt; Attribute\n The [SVG `u1` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/u1)\nSynonyms:\nsprocket/html/svg/attributes.u1\nsprocket/html/svg/attributes u1","url":"sprocket/html/svg/attributes.html#u1"},{"doc":"sprocket/html/svg/attributes","title":"u2","content":"pub fn u2(value: String) -&gt; Attribute\n The [SVG `u2` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/u2)\nSynonyms:\nsprocket/html/svg/attributes.u2\nsprocket/html/svg/attributes u2","url":"sprocket/html/svg/attributes.html#u2"},{"doc":"sprocket/html/svg/attributes","title":"underline_position","content":"pub fn underline_position(value: String) -&gt; Attribute\n The [SVG `underline-position` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/underline-position)\nSynonyms:\nsprocket/html/svg/attributes.underline_position\nsprocket/html/svg/attributes underline_position","url":"sprocket/html/svg/attributes.html#underline_position"},{"doc":"sprocket/html/svg/attributes","title":"underline_thickness","content":"pub fn underline_thickness(value: String) -&gt; Attribute\n The [SVG `underline-thickness` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/underline-thickness)\nSynonyms:\nsprocket/html/svg/attributes.underline_thickness\nsprocket/html/svg/attributes underline_thickness","url":"sprocket/html/svg/attributes.html#underline_thickness"},{"doc":"sprocket/html/svg/attributes","title":"unicode","content":"pub fn unicode(value: String) -&gt; Attribute\n The [SVG `unicode` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/unicode)\nSynonyms:\nsprocket/html/svg/attributes.unicode\nsprocket/html/svg/attributes unicode","url":"sprocket/html/svg/attributes.html#unicode"},{"doc":"sprocket/html/svg/attributes","title":"unicode_bidi","content":"pub fn unicode_bidi(value: String) -&gt; Attribute\n The [SVG `unicode-bidi` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/unicode-bidi)\nSynonyms:\nsprocket/html/svg/attributes.unicode_bidi\nsprocket/html/svg/attributes unicode_bidi","url":"sprocket/html/svg/attributes.html#unicode_bidi"},{"doc":"sprocket/html/svg/attributes","title":"unicode_range","content":"pub fn unicode_range(value: String) -&gt; Attribute\n The [SVG `unicode-range` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/unicode-range)\nSynonyms:\nsprocket/html/svg/attributes.unicode_range\nsprocket/html/svg/attributes unicode_range","url":"sprocket/html/svg/attributes.html#unicode_range"},{"doc":"sprocket/html/svg/attributes","title":"units_per_em","content":"pub fn units_per_em(value: String) -&gt; Attribute\n The [SVG `units-per-em` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/units-per-em)\nSynonyms:\nsprocket/html/svg/attributes.units_per_em\nsprocket/html/svg/attributes units_per_em","url":"sprocket/html/svg/attributes.html#units_per_em"},{"doc":"sprocket/html/svg/attributes","title":"v_alphabetic","content":"pub fn v_alphabetic(value: String) -&gt; Attribute\n The [SVG `v-alphabetic` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/v-alphabetic)\nSynonyms:\nsprocket/html/svg/attributes.v_alphabetic\nsprocket/html/svg/attributes v_alphabetic","url":"sprocket/html/svg/attributes.html#v_alphabetic"},{"doc":"sprocket/html/svg/attributes","title":"v_hanging","content":"pub fn v_hanging(value: String) -&gt; Attribute\n The [SVG `v-hanging` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/v-hanging)\nSynonyms:\nsprocket/html/svg/attributes.v_hanging\nsprocket/html/svg/attributes v_hanging","url":"sprocket/html/svg/attributes.html#v_hanging"},{"doc":"sprocket/html/svg/attributes","title":"v_ideographic","content":"pub fn v_ideographic(value: String) -&gt; Attribute\n The [SVG `v-ideographic` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/v-ideographic)\nSynonyms:\nsprocket/html/svg/attributes.v_ideographic\nsprocket/html/svg/attributes v_ideographic","url":"sprocket/html/svg/attributes.html#v_ideographic"},{"doc":"sprocket/html/svg/attributes","title":"v_mathematical","content":"pub fn v_mathematical(value: String) -&gt; Attribute\n The [SVG `v-mathematical` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/v-mathematical)\nSynonyms:\nsprocket/html/svg/attributes.v_mathematical\nsprocket/html/svg/attributes v_mathematical","url":"sprocket/html/svg/attributes.html#v_mathematical"},{"doc":"sprocket/html/svg/attributes","title":"values","content":"pub fn values(value: String) -&gt; Attribute\n The [SVG `values` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/values)\nSynonyms:\nsprocket/html/svg/attributes.values\nsprocket/html/svg/attributes values","url":"sprocket/html/svg/attributes.html#values"},{"doc":"sprocket/html/svg/attributes","title":"vector_effect","content":"pub fn vector_effect(value: String) -&gt; Attribute\n The [SVG `vector-effect` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/vector-effect)\nSynonyms:\nsprocket/html/svg/attributes.vector_effect\nsprocket/html/svg/attributes vector_effect","url":"sprocket/html/svg/attributes.html#vector_effect"},{"doc":"sprocket/html/svg/attributes","title":"version","content":"pub fn version(value: String) -&gt; Attribute\n The [SVG `version` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/version)\nSynonyms:\nsprocket/html/svg/attributes.version\nsprocket/html/svg/attributes version","url":"sprocket/html/svg/attributes.html#version"},{"doc":"sprocket/html/svg/attributes","title":"vert_adv_y","content":"pub fn vert_adv_y(value: String) -&gt; Attribute\n The [SVG `vert-adv-y` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/vert-adv-y)\nSynonyms:\nsprocket/html/svg/attributes.vert_adv_y\nsprocket/html/svg/attributes vert_adv_y","url":"sprocket/html/svg/attributes.html#vert_adv_y"},{"doc":"sprocket/html/svg/attributes","title":"vert_origin_x","content":"pub fn vert_origin_x(value: String) -&gt; Attribute\n The [SVG `vert-origin-x` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/vert-origin-x)\nSynonyms:\nsprocket/html/svg/attributes.vert_origin_x\nsprocket/html/svg/attributes vert_origin_x","url":"sprocket/html/svg/attributes.html#vert_origin_x"},{"doc":"sprocket/html/svg/attributes","title":"vert_origin_y","content":"pub fn vert_origin_y(value: String) -&gt; Attribute\n The [SVG `vert-origin-y` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/vert-origin-y)\nSynonyms:\nsprocket/html/svg/attributes.vert_origin_y\nsprocket/html/svg/attributes vert_origin_y","url":"sprocket/html/svg/attributes.html#vert_origin_y"},{"doc":"sprocket/html/svg/attributes","title":"view_box","content":"pub fn view_box(value: String) -&gt; Attribute\n The [SVG `viewBox` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/viewBox)\nSynonyms:\nsprocket/html/svg/attributes.view_box\nsprocket/html/svg/attributes view_box","url":"sprocket/html/svg/attributes.html#view_box"},{"doc":"sprocket/html/svg/attributes","title":"view_target","content":"pub fn view_target(value: String) -&gt; Attribute\n The [SVG `viewTarget` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/viewTarget)\nSynonyms:\nsprocket/html/svg/attributes.view_target\nsprocket/html/svg/attributes view_target","url":"sprocket/html/svg/attributes.html#view_target"},{"doc":"sprocket/html/svg/attributes","title":"visibility","content":"pub fn visibility(value: String) -&gt; Attribute\n The [SVG `visibility` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/visibility)\nSynonyms:\nsprocket/html/svg/attributes.visibility\nsprocket/html/svg/attributes visibility","url":"sprocket/html/svg/attributes.html#visibility"},{"doc":"sprocket/html/svg/attributes","title":"width","content":"pub fn width(value: String) -&gt; Attribute\n The [SVG `width` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/width)\nSynonyms:\nsprocket/html/svg/attributes.width\nsprocket/html/svg/attributes width","url":"sprocket/html/svg/attributes.html#width"},{"doc":"sprocket/html/svg/attributes","title":"widths","content":"pub fn widths(value: String) -&gt; Attribute\n The [SVG `widths` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/widths)\nSynonyms:\nsprocket/html/svg/attributes.widths\nsprocket/html/svg/attributes widths","url":"sprocket/html/svg/attributes.html#widths"},{"doc":"sprocket/html/svg/attributes","title":"word_spacing","content":"pub fn word_spacing(value: String) -&gt; Attribute\n The [SVG `word-spacing` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/word-spacing)\nSynonyms:\nsprocket/html/svg/attributes.word_spacing\nsprocket/html/svg/attributes word_spacing","url":"sprocket/html/svg/attributes.html#word_spacing"},{"doc":"sprocket/html/svg/attributes","title":"writing_mode","content":"pub fn writing_mode(value: String) -&gt; Attribute\n The [SVG `writing-mode` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/writing-mode)\nSynonyms:\nsprocket/html/svg/attributes.writing_mode\nsprocket/html/svg/attributes writing_mode","url":"sprocket/html/svg/attributes.html#writing_mode"},{"doc":"sprocket/html/svg/attributes","title":"x","content":"pub fn x(value: String) -&gt; Attribute\n The [SVG `x` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/x)\nSynonyms:\nsprocket/html/svg/attributes.x\nsprocket/html/svg/attributes x","url":"sprocket/html/svg/attributes.html#x"},{"doc":"sprocket/html/svg/attributes","title":"x1","content":"pub fn x1(value: String) -&gt; Attribute\n The [SVG `x1` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/x1)\nSynonyms:\nsprocket/html/svg/attributes.x1\nsprocket/html/svg/attributes x1","url":"sprocket/html/svg/attributes.html#x1"},{"doc":"sprocket/html/svg/attributes","title":"x2","content":"pub fn x2(value: String) -&gt; Attribute\n The [SVG `x2` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/x2)\nSynonyms:\nsprocket/html/svg/attributes.x2\nsprocket/html/svg/attributes x2","url":"sprocket/html/svg/attributes.html#x2"},{"doc":"sprocket/html/svg/attributes","title":"x_channel_selector","content":"pub fn x_channel_selector(value: String) -&gt; Attribute\n The [SVG `xChannelSelector` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xChannelSelector)\nSynonyms:\nsprocket/html/svg/attributes.x_channel_selector\nsprocket/html/svg/attributes x_channel_selector","url":"sprocket/html/svg/attributes.html#x_channel_selector"},{"doc":"sprocket/html/svg/attributes","title":"x_height","content":"pub fn x_height(value: String) -&gt; Attribute\n The [SVG `x-height` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/x-height)\nSynonyms:\nsprocket/html/svg/attributes.x_height\nsprocket/html/svg/attributes x_height","url":"sprocket/html/svg/attributes.html#x_height"},{"doc":"sprocket/html/svg/attributes","title":"xlink_actuate","content":"pub fn xlink_actuate(value: String) -&gt; Attribute\n The [SVG `xlink:actuate` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:actuate)\nSynonyms:\nsprocket/html/svg/attributes.xlink_actuate\nsprocket/html/svg/attributes xlink_actuate","url":"sprocket/html/svg/attributes.html#xlink_actuate"},{"doc":"sprocket/html/svg/attributes","title":"xlink_arcrole","content":"pub fn xlink_arcrole(value: String) -&gt; Attribute\n The [SVG `xlink:arcrole` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:arcrole)\nSynonyms:\nsprocket/html/svg/attributes.xlink_arcrole\nsprocket/html/svg/attributes xlink_arcrole","url":"sprocket/html/svg/attributes.html#xlink_arcrole"},{"doc":"sprocket/html/svg/attributes","title":"xlink_href","content":"pub fn xlink_href(value: String) -&gt; Attribute\n The [SVG `xlink:href` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:href)\nSynonyms:\nsprocket/html/svg/attributes.xlink_href\nsprocket/html/svg/attributes xlink_href","url":"sprocket/html/svg/attributes.html#xlink_href"},{"doc":"sprocket/html/svg/attributes","title":"xlink_role","content":"pub fn xlink_role(value: String) -&gt; Attribute\n The [SVG `xlink:role` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:role)\nSynonyms:\nsprocket/html/svg/attributes.xlink_role\nsprocket/html/svg/attributes xlink_role","url":"sprocket/html/svg/attributes.html#xlink_role"},{"doc":"sprocket/html/svg/attributes","title":"xlink_show","content":"pub fn xlink_show(value: String) -&gt; Attribute\n The [SVG `xlink:show` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:show)\nSynonyms:\nsprocket/html/svg/attributes.xlink_show\nsprocket/html/svg/attributes xlink_show","url":"sprocket/html/svg/attributes.html#xlink_show"},{"doc":"sprocket/html/svg/attributes","title":"xlink_title","content":"pub fn xlink_title(value: String) -&gt; Attribute\n The [SVG `xlink:title` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:title)\nSynonyms:\nsprocket/html/svg/attributes.xlink_title\nsprocket/html/svg/attributes xlink_title","url":"sprocket/html/svg/attributes.html#xlink_title"},{"doc":"sprocket/html/svg/attributes","title":"xlink_type","content":"pub fn xlink_type(value: String) -&gt; Attribute\n The [SVG `xlink:type` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:type)\nSynonyms:\nsprocket/html/svg/attributes.xlink_type\nsprocket/html/svg/attributes xlink_type","url":"sprocket/html/svg/attributes.html#xlink_type"},{"doc":"sprocket/html/svg/attributes","title":"xml_base","content":"pub fn xml_base(value: String) -&gt; Attribute\n The [SVG `xml:base` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xml:base)\nSynonyms:\nsprocket/html/svg/attributes.xml_base\nsprocket/html/svg/attributes xml_base","url":"sprocket/html/svg/attributes.html#xml_base"},{"doc":"sprocket/html/svg/attributes","title":"xml_lang","content":"pub fn xml_lang(value: String) -&gt; Attribute\n The [SVG `xml:lang` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xml:lang)\nSynonyms:\nsprocket/html/svg/attributes.xml_lang\nsprocket/html/svg/attributes xml_lang","url":"sprocket/html/svg/attributes.html#xml_lang"},{"doc":"sprocket/html/svg/attributes","title":"xml_space","content":"pub fn xml_space(value: String) -&gt; Attribute\n The [SVG `xml:space` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xml:space)\nSynonyms:\nsprocket/html/svg/attributes.xml_space\nsprocket/html/svg/attributes xml_space","url":"sprocket/html/svg/attributes.html#xml_space"},{"doc":"sprocket/html/svg/attributes","title":"y","content":"pub fn y(value: String) -&gt; Attribute\n The [SVG `y` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/y)\nSynonyms:\nsprocket/html/svg/attributes.y\nsprocket/html/svg/attributes y","url":"sprocket/html/svg/attributes.html#y"},{"doc":"sprocket/html/svg/attributes","title":"y1","content":"pub fn y1(value: String) -&gt; Attribute\n The [SVG `y1` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/y1)\nSynonyms:\nsprocket/html/svg/attributes.y1\nsprocket/html/svg/attributes y1","url":"sprocket/html/svg/attributes.html#y1"},{"doc":"sprocket/html/svg/attributes","title":"y2","content":"pub fn y2(value: String) -&gt; Attribute\n The [SVG `y2` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/y2)\nSynonyms:\nsprocket/html/svg/attributes.y2\nsprocket/html/svg/attributes y2","url":"sprocket/html/svg/attributes.html#y2"},{"doc":"sprocket/html/svg/attributes","title":"y_channel_selector","content":"pub fn y_channel_selector(value: String) -&gt; Attribute\n The [SVG `yChannelSelector` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/yChannelSelector)\nSynonyms:\nsprocket/html/svg/attributes.y_channel_selector\nsprocket/html/svg/attributes y_channel_selector","url":"sprocket/html/svg/attributes.html#y_channel_selector"},{"doc":"sprocket/html/svg/attributes","title":"z","content":"pub fn z(value: String) -&gt; Attribute\n The [SVG `z` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/z)\nSynonyms:\nsprocket/html/svg/attributes.z\nsprocket/html/svg/attributes z","url":"sprocket/html/svg/attributes.html#z"},{"doc":"sprocket/html/svg/attributes","title":"zoom_and_pan","content":"pub fn zoom_and_pan(value: String) -&gt; Attribute\n The [SVG `zoomAndPan` attribute](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/zoomAndPan)\nSynonyms:\nsprocket/html/svg/attributes.zoom_and_pan\nsprocket/html/svg/attributes zoom_and_pan","url":"sprocket/html/svg/attributes.html#zoom_and_pan"},{"doc":"sprocket/html/svg/attributes","title":"sprocket/html/svg/attributes","content":"","url":"sprocket/html/svg/attributes.html"},{"doc":"sprocket/hooks/client","title":"client","content":"pub fn client(ctx: Context, name: String, handle_event: Option(\n    fn(\n      String,\n      Option(Dynamic),\n      fn(String, Option(String)) -&gt; Result(Nil, Nil),\n    ) -&gt; Nil,\n  ), cb: fn(\n    Context,\n    fn() -&gt; Attribute,\n    fn(String, Option(String)) -&gt; Result(Nil, Nil),\n  ) -&gt; #(Context, List(Element))) -&gt; #(Context, List(Element))\n\nSynonyms:\nsprocket/hooks/client.client\nsprocket/hooks/client client","url":"sprocket/hooks/client.html#client"},{"doc":"sprocket/hooks/client","title":"sprocket/hooks/client","content":"","url":"sprocket/hooks/client.html"},{"doc":"tools/html_transform","title":"main","content":"pub fn main() -&gt; Nil\n A very fragile script to transform a file of html tags into sprocket element/attribute functions\n \n \n &lt;a&gt;\n &lt;animate&gt;\n &lt;animateMotion&gt;\n &lt;animateTransform&gt;\n ...\n \n \n Example:\n &gt; gleam run -m tools/html_transform -- --template=elements src/sprocket/html/svg/source/elements\n \n Will create a file src/sprocket/html/svg.gleam\n \nSynonyms:\ntools/html_transform.main\ntools/html_transform main","url":"tools/html_transform.html#main"},{"doc":"tools/html_transform","title":"snake_case","content":"pub fn snake_case(input: String) -&gt; String\n\nSynonyms:\ntools/html_transform.snake_case\ntools/html_transform snake_case","url":"tools/html_transform.html#snake_case"},{"doc":"tools/html_transform","title":"tools/html_transform","content":"","url":"tools/html_transform.html"},{"doc":"sprocket","title":"main","content":"pub fn main() -&gt; Nil\n The main function is the entry point of the docs demo\nSynonyms:\nsprocket.main\nsprocket main","url":"sprocket.html#main"},{"doc":"sprocket","title":"sprocket","content":"","url":"sprocket.html"}]);